@@ -1,14 +1,27 @@
 // CvsDirectory.java
-// $Id: CvsDirectory.java,v 1.63 1999/03/23 10:19:48 bmahe Exp $  
+// $Id: CvsDirectory.java,v 1.64 2000/08/16 21:37:25 ylafon Exp $  
 // (c) COPYRIGHT MIT and INRIA, 1997.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.cvs;
 
-import java.util.*;
-import java.io.*;
+import java.util.Enumeration;
+import java.util.Hashtable;
+import java.util.Properties;
+import java.util.StringTokenizer;
 
-import org.w3c.util.*;
+import java.io.DataInputStream;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FilenameFilter;
+import java.io.FilterInputStream;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.io.PrintStream;
+
+import org.w3c.util.AsyncLRUList;
+import org.w3c.util.LRUAble;
+import org.w3c.util.LRUList;
 
 //
 // FIXME add extra environment parameter to all public methods
@@ -71,7 +84,6 @@ public class CvsDirectory implements LRUAble, CVS {
      */
     protected static int cachesize = 32;
 
-
     /**
      * LRU management - previous entry.
      */
@@ -113,12 +125,11 @@ public class CvsDirectory implements LRUAble, CVS {
      */
     public Properties props = null;
 
-
     String cvspath      = cvspath_def ;
     String cvsroot      = cvsroot_def ;
     String cvswrapper[] = { cvswrap_def } ;
 
-    
+   
     /**
      * This one is the third copy of the same piece of code (!)
      * Parse the given prop value into an array of | separated components.
@@ -274,7 +285,7 @@ public class CvsDirectory implements LRUAble, CVS {
      * LRU management - Get next node.
      * @return A CvsDirectory instance.
      */
-    
+
     public LRUAble getNext() {
 	return next;
     }
@@ -283,7 +294,7 @@ public class CvsDirectory implements LRUAble, CVS {
      * LRU management - Get previous node.
      * @return A CvsDirectory instance.
      */
-    
+
     public LRUAble getPrev() {
 	return prev;
     }
@@ -292,7 +303,7 @@ public class CvsDirectory implements LRUAble, CVS {
      * LRU management - Set next node.
      * @return A CvsDirectory instance.
      */
-    
+
     public void setNext(LRUAble next) {
 	this.next = next;
     }
@@ -301,7 +312,7 @@ public class CvsDirectory implements LRUAble, CVS {
      * LRU management - Set previous node.
      * @return A CvsDirectory instance.
      */
-    
+
     public void setPrev(LRUAble prev) {
 	this.prev = prev;
     }
@@ -1051,7 +1062,7 @@ public class CvsDirectory implements LRUAble, CVS {
 	    prt.println("*** CVS Error: "+ex.getMessage());
 	}
     }
-     
+
     /**
      * Get a sub-directory status.
      * @param subdir The name of the subdirectory.
@@ -1110,7 +1121,7 @@ public class CvsDirectory implements LRUAble, CVS {
      * Get the directory controlled by this manager.
      * @return A File instance locating the directory.
      */
-    
+
     public File getDirectory() {
 	return directory;
     }
