@@ -1,5 +1,5 @@
 // SlideIntegerAttributeEditor.java
-// $Id: SlideIntegerAttributeEditor.java,v 1.3 1999/09/08 13:11:20 bmahe Exp $
+// $Id: SlideIntegerAttributeEditor.java,v 1.5 2000/10/31 15:08:45 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1997.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
@@ -19,7 +19,6 @@ import org.w3c.jigsaw.admin.RemoteResource;
 import org.w3c.jigadm.RemoteResourceWrapper;
 import org.w3c.jigadm.editors.AttributeEditor;
 
-
 /**
  * SlideIntegerAttributeEditor :
  * @author Benoit Mahe <bmahe@sophia.inria.fr>
@@ -104,6 +103,15 @@ public class SlideIntegerAttributeEditor extends AttributeEditor {
 	max   = (max < 0 ? 0 : max);
 	step  = (step < 0 ? 0 : step);
 	value = (value < 0 ? 0 : value);
+	if (min > max) {
+	    min = max;
+	}
+	if (value <= min ) {
+	    min = Math.max(0, value - (max - min) / 5 );
+	}
+	if (value >= max ) {
+	    max = value + (max - min) / 5;
+	}
 	EditableSlider slider = new EditableSlider(min, max, step, value);
 	return slider;
     }
