@@ -1,8 +1,8 @@
 // AclFilter.java
-// $Id: AclFilter.java,v 1.7 2000/01/21 13:40:21 ylafon Exp $
+// $Id: AclFilter.java,v 1.9 2000/12/07 14:30:33 ylafon Exp $
 // (c) COPYRIGHT MIT, INRIA and Keio, 1999.
 // Please first read the full copyright statement in file COPYRIGHT.html
- 
+
 package org.w3c.jigsaw.acl;
 
 import java.security.Principal;
@@ -31,7 +31,7 @@ import org.w3c.www.http.HTTP;
 import org.w3c.www.http.HttpChallenge;
 
 /**
- * @version $Revision: 1.7 $
+ * @version $Revision: 1.9 $
  * @author  Benot Mah (bmahe@w3.org)
  */
 public class AclFilter extends ResourceFilter {
@@ -255,7 +255,7 @@ public class AclFilter extends ResourceFilter {
 	    security.updateRequestStates(request, princ);
 	}
     }
-    
+
     /**
      * Add the appropriate cache control directives on the way back.
      * @param request The request that has been processed.
@@ -282,11 +282,11 @@ public class AclFilter extends ResourceFilter {
      */
     public void setValue(int idx, Object value) {
 	super.setValue(idx, value);
-	if (idx == ATTR_SECURITY_LEVEL) {
+	if ((idx == ATTR_SECURITY_LEVEL) || (idx == ATTR_ALGORITHM )) {
 	    security = SecurityLevel.getSecurityLevel(this);
 	}
     }
-    
+
     /**
      * Initialize the filter.
      */
