@@ -1,31 +1,46 @@
 // PlainRemoteResource.java
-// $Id: PlainRemoteResource.java,v 1.25.4.2 2000/02/18 15:14:05 bmahe Exp $
+// $Id: PlainRemoteResource.java,v 1.31 2000/08/16 21:37:34 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1997.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.admin;
 
-import java.io.*;
-import java.net.*;
-import java.util.*;
-import java.lang.*;
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.io.PrintStream;
+
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.net.URLEncoder;
+
+import java.util.zip.GZIPInputStream;
+import java.util.zip.GZIPOutputStream;
 
 import org.w3c.tools.resources.Attribute;
-import org.w3c.www.protocol.http.*;
+import org.w3c.tools.resources.SimpleAttribute;
+import org.w3c.tools.resources.ArrayAttribute;
+
+import org.w3c.tools.resources.serialization.AttributeDescription;
+import org.w3c.tools.resources.serialization.EmptyDescription;
+import org.w3c.tools.resources.serialization.ResourceDescription;
+
+import org.w3c.www.protocol.http.HttpManager;
+import org.w3c.www.protocol.http.Reply;
+import org.w3c.www.protocol.http.Request;
 
 public class PlainRemoteResource implements RemoteResource {
+    private static final boolean debug = false;
     /**
      * The client side admin context
      */
     protected AdminContext admin = null;
-    /**
-     * The remote resource class hierarchy.
-     */
-    protected String classes[] = null;
     /**
      * The remote resource set of attributes.
      */
-    protected Attribute attributes[];
+    protected AttributeDescription attributes[];
     /**
      * The remote resource attribute values.
      */
@@ -62,24 +77,27 @@ public class PlainRemoteResource implements RemoteResource {
      * Set of attached frames.
      */
     protected RemoteResource frames[] = null;
+    /**
+     * Our description
+     */
+    protected ResourceDescription description = null;
 
     protected Request createRequest() {
 	Request request = admin.http.createRequest();
 	request.setURL(url);
+	if (!debug) {
+	    request.setValue("TE", "gzip");
+	}
 	return request;
     }
 
-    protected int lookupAttribute(String attr) 
-	throws RemoteAccessException
+    protected InputStream getInputStream(Reply reply) 
+	throws IOException
     {
-	Attribute attrs[] = getAttributes();
-	for (int i = 0  ; i < attrs.length ; i++) {
-	    if ( attrs[i] == null )
-		continue;
-	    if ( attrs[i].getName().equals(attr) )
-		return i;
-	}
-	return -1;
+	if (reply.hasTransferEncoding("gzip"))
+	    return new GZIPInputStream(reply.getInputStream());
+	else
+	    return reply.getInputStream();	
     }
 
     protected void setFrames(RemoteResource frames[]) {
@@ -99,7 +117,7 @@ public class PlainRemoteResource implements RemoteResource {
     public String[] getClassHierarchy()
 	throws RemoteAccessException
     {
-	return classes;
+	return description.getClassHierarchy();
     }
 
     /**
@@ -127,8 +145,8 @@ public class PlainRemoteResource implements RemoteResource {
 		throw new RemoteAccessException(ex.getMessage());
 	    }
 	} else {
-	    throw new RemoteAccessException("Error, can't reindex! this is not"+
-					    " a DirectoryResource.");
+	    throw new RemoteAccessException("Error, can't reindex! This is "+
+					    "not a DirectoryResource.");
 	}
     }
 
@@ -136,7 +154,6 @@ public class PlainRemoteResource implements RemoteResource {
      * Delete that resource, and detach it from its container.
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-
     public void delete()
 	throws RemoteAccessException
     {
@@ -165,20 +182,10 @@ public class PlainRemoteResource implements RemoteResource {
      * @return An array of Attribute.
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-
-    public synchronized Attribute[] getAttributes()
+    public synchronized AttributeDescription[] getAttributes()
 	throws RemoteAccessException
     {
-	if ( attributes == null ) {
-	    // Load this class attributes:
-	    try {
-		attributes = admin.getAttributes(classes[0]);
-	    } catch (InvalidResourceClass ex) {
-		// Probably (?) an implementation bug...
-		throw new RuntimeException("invalid class "+classes[0]);
-	    }
-	}
-	return attributes;
+	return description.getAttributeDescriptions();
     }
 
     /**
@@ -198,61 +205,35 @@ public class PlainRemoteResource implements RemoteResource {
 	return getValues(attrs)[0];
     }
 
+    protected AttributeDescription lookupAttribute(String name) {
+	AttributeDescription attds[] = description.getAttributeDescriptions();
+	for (int i = 0 ; i < attds.length ; i++) {
+	    AttributeDescription ad = attds[i];
+	    if (ad.getName().equals(name))
+		return ad;
+	}
+	return null;
+    }
+
     /**
      * @param attrs The (ordered) set of attributes whose value is to be
      * fetched.
      * @return An (ordered) set of values, one per queried attribute.
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-
     public Object[] getValues(String attrs[])
 	throws RemoteAccessException
     {
-	// Before going out to the server, check the cache:
-	// FIXME
-
-	// Load the attribute values:
-	ByteArrayOutputStream bout = new ByteArrayOutputStream();
-	DataOutputStream      out  = new DataOutputStream(bout);
-	try {
-	    // Write out the query body:
-	    for (int i = 0 ; i < attrs.length ; i++) {
-		int idx = lookupAttribute(attrs[i]);
-		if ( idx < 0 )
-		    throw new RuntimeException("invalid attribute "+attrs[i]);
-		out.writeInt(idx);
+	Object values[] = new Object[attrs.length];
+	for (int i = 0 ; i < attrs.length ; i++) {
+	    AttributeDescription ad = lookupAttribute(attrs[i]);
+	    if (ad != null) {
+		values[i] = ad.getValue();
+	    } else {
+		values[i] = null;
 	    }
-	    out.writeInt(-1);
-	    out.close();
-	    byte bits[] = bout.toByteArray();
-	    // Write the tunnelling HTTP request:
-	    Request req = createRequest();
-	    req.setMethod("GET-VALUES");
-	    req.setContentType(admin.conftype);
-	    req.setContentLength(bits.length);
-	    req.setOutputStream(new ByteArrayInputStream(bits));
-	    // Run that request:
-	    Reply rep = admin.runRequest(req);
-	    // Parse the admin reply:
-	    DataInputStream in    = new DataInputStream(rep.getInputStream());
-	    int             idx   = -1;
-	    Object          ret[] = new Object[attrs.length];
-	    int             reti  = 0;
-	    while ((idx = in.readInt()) != -1) {
-		if ( idx >= 0 ) {
-		    Attribute a = attributes[idx];
-		    ret[reti] = a.unpickle(in);
-		}
-		reti++;
-	    }
-	    in.close();
-	    return ret;
-	} catch (RemoteAccessException rae) {
-	    throw rae;
-	} catch (Exception ex) {
-	    ex.printStackTrace();
-	    throw new RemoteAccessException("exception "+ex.getMessage());
 	}
+	return values;
     }
 
     /**
@@ -281,37 +262,48 @@ public class PlainRemoteResource implements RemoteResource {
      * attributes.
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-
     public void setValues(String names[], Object values[])
 	throws RemoteAccessException
     {
-	// Prepare the output:
-	Attribute             attrs[] = getAttributes();
-	ByteArrayOutputStream bout    = new ByteArrayOutputStream();
-	DataOutputStream      out     = new DataOutputStream(bout);
-	boolean               change  = false;
-	String                newId   = null;
-	try {
-	    // Write out the query body:
-	    for (int i = 0 ; i < names.length ; i++) {
-		int       idx = lookupAttribute(names[i]);
-		Attribute a   = attrs[idx];
-		out.writeInt(idx);
-		a.pickle(out, values[i]);
-		if(names[i].equals("identifier")) {
-		    change = true;
-		    newId = (String) values[i];
-		}
+	String  newId  = null;
+	boolean change = false;
+
+	AttributeDescription attrs[] = new AttributeDescription[names.length];
+
+	for (int i = 0 ; i < names.length ; i++) {
+	    AttributeDescription ad = lookupAttribute(names[i]);
+	    if (ad != null) {
+		ad.setValue(values[i]);
+		attrs[i] = ad;
 	    }
-	    out.writeInt(-1);
-	    out.close();
+	    if (names[i].equals("identifier")) {
+		change = true;
+		newId = (String) values[i];
+	    }
+	}
+
+	ResourceDescription descr = description.getClone(attrs);
+
+	try {
+	    ByteArrayOutputStream bout = new ByteArrayOutputStream();
+	    OutputStream out;
+	    if (debug) {
+		out = bout;
+	    } else {
+		out = new GZIPOutputStream(bout);
+	    }
+	    admin.writer.writeResourceDescription(descr, out);
 	    byte bits[] = bout.toByteArray();
-	    // Write the tunnelling HTTP request:
+
 	    Request req = createRequest();
 	    req.setMethod("SET-VALUES");
 	    req.setContentType(admin.conftype);
 	    req.setContentLength(bits.length);
+	    if (!debug) {
+		req.addTransferEncoding("gzip");
+	    }
 	    req.setOutputStream(new ByteArrayInputStream(bits));
+	
 	    // Run that request:
 	    Reply rep = admin.runRequest(req);
 	} catch (RemoteAccessException rae) {
@@ -320,6 +312,7 @@ public class PlainRemoteResource implements RemoteResource {
 	    ex.printStackTrace();
 	    throw new RemoteAccessException("exception "+ex.getMessage());
 	}
+
 	if(change) {
 	    identifier = new String(newId);
 	    try {
@@ -372,7 +365,8 @@ public class PlainRemoteResource implements RemoteResource {
 	    if(identifier.equals("root"))
 		return false;
 	    if(identifier.equals("control")) {
-		if(classes[0].equals("org.w3c.jigsaw.http.ControlResource"))
+		String classname = getClassHierarchy()[0];
+		if(classname.equals("org.w3c.jigsaw.http.ControlResource"))
 		    return false;
 	    }
 	}
@@ -406,31 +400,14 @@ public class PlainRemoteResource implements RemoteResource {
     /**
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-
     public String[] enumerateResourceIdentifiers()
 	throws RemoteAccessException
     {
 	if ( ! iscontainer )
 	    throw new RuntimeException("not a container");
 	try {
-	    // Send the request:
-	    Request req = createRequest();
-	    req.setMethod("ENUMERATE-IDENTIFIERS");
-	    // Get and check the reply:
-	    Reply rep = admin.runRequest(req);
-	    // Decode the result:
-	    DataInputStream in   = new DataInputStream(rep.getInputStream());
-	    Vector          vids = new Vector();
-	    String          id   = null;
-	    while (! (id = in.readUTF()).equals(""))
-		vids.addElement(id);
-	    in.close();
-	    // Wrapup the result
-	    String ids[] = new String[vids.size()];
-	    vids.copyInto(ids);
-	    return ids;
-	} catch (RemoteAccessException rae) {
-	    throw rae;
+	    update();
+	    return description.getChildren();
 	} catch (Exception ex) {
 	    ex.printStackTrace();
 	    throw new RemoteAccessException("http "+ex.getMessage());
@@ -453,8 +430,9 @@ public class PlainRemoteResource implements RemoteResource {
 	    // Run it:
 	    Reply rep = admin.runRequest(req);
 	    // Decode the reply:
-	    DataInputStream in  = new DataInputStream(rep.getInputStream());
-	    RemoteResource  ret = admin.reader.readResource(url,identifier,in);
+	    InputStream in = getInputStream(rep);
+	    RemoteResource  ret = 
+		admin.reader.readResource(url,identifier,in);
 	    in.close();
 	    return ret;
 	} catch (RemoteAccessException rae) {
@@ -471,30 +449,38 @@ public class PlainRemoteResource implements RemoteResource {
      * @param classname The name of the class of the resource to be added.
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-
     public RemoteResource registerResource(String id, String classname) 
 	throws RemoteAccessException
     {
-	ByteArrayOutputStream bout    = new ByteArrayOutputStream();
-	DataOutputStream      out     = new DataOutputStream(bout);
+	ResourceDescription   rd   = new EmptyDescription(classname, id);
 	try {
 	    Request req = createRequest();
 	    // Prepare the request:
 	    req.setMethod("REGISTER-RESOURCE");
 	    req.setContentType(admin.conftype);
 	    req.setURL(url);
-	    out.writeUTF(id);
-	    out.writeUTF(classname);
-	    out.close();
-	    byte bits[] = bout.toByteArray();	    
+	    ByteArrayOutputStream bout = new ByteArrayOutputStream();
+	    OutputStream out;
+	    if (debug) {
+		out = bout;
+	    } else { 
+		out = new GZIPOutputStream(bout);
+	    }
+	    admin.writer.writeResourceDescription(rd, out);
+	    byte bits[] = bout.toByteArray();
 	    req.setContentLength(bits.length);
+	    if (!debug) {
+		req.addTransferEncoding("gzip");
+	    }
 	    req.setOutputStream(new ByteArrayInputStream(bits));
 	    // Run it:
 	    Reply rep = admin.runRequest(req);
+
 	    // Decode the result:
-	    DataInputStream in  = new DataInputStream(rep.getInputStream());
-	    RemoteResource  ret = admin.reader.readResource(url, id, in);
-	    in.close();
+	    rd = admin.reader.readResourceDescription(getInputStream(rep));
+	    RemoteResource ret = 
+		new PlainRemoteResource(admin, url, rd.getIdentifier(), rd);
+	    
 	    return ret;
 	} catch (RemoteAccessException rae) {
 	    throw rae;
@@ -526,7 +512,7 @@ public class PlainRemoteResource implements RemoteResource {
      * to that resource.
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-  
+
     public RemoteResource[] getFrames()
 	throws RemoteAccessException
     {
@@ -540,7 +526,6 @@ public class PlainRemoteResource implements RemoteResource {
      * @param frame The frame to unregister.
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-  
     public void unregisterFrame(RemoteResource frame)
 	throws RemoteAccessException
     {
@@ -549,8 +534,6 @@ public class PlainRemoteResource implements RemoteResource {
 	if ( frames == null )
 	    throw new RuntimeException("this resource has no frames");
 	// Remove it:
-	ByteArrayOutputStream bout    = new ByteArrayOutputStream();
-	DataOutputStream      out     = new DataOutputStream(bout);
 	String id = null;
 	try {
 	    id = ((PlainRemoteResource)frame).identifier;
@@ -559,11 +542,23 @@ public class PlainRemoteResource implements RemoteResource {
 	    req.setMethod("UNREGISTER-FRAME");
 	    req.setContentType(admin.conftype);
 	    req.setURL(url);
-	    out.writeUTF((id== null) ? "" : id);
-	    out.close();
-	    byte bits[] = bout.toByteArray();    
+
+	    ResourceDescription dframe = new EmptyDescription("", id);
+	    ByteArrayOutputStream bout = new ByteArrayOutputStream();
+	    OutputStream out;
+	    if (debug) {
+		out = bout;
+	    } else {
+		out = new GZIPOutputStream(bout);
+	    }
+	    admin.writer.writeResourceDescription(dframe, out);
+	    byte bits[] = bout.toByteArray();
 	    req.setContentLength(bits.length);
+	    if (!debug) {
+		req.addTransferEncoding("gzip");
+	    }
 	    req.setOutputStream(new ByteArrayInputStream(bits));
+
 	    // Run it:
 	    Reply rep = admin.runRequest(req);	
 	} catch (RemoteAccessException rae) {
@@ -605,55 +600,60 @@ public class PlainRemoteResource implements RemoteResource {
      * @return A remote handle to the (remotely) created frame instance.
      * @exception RemoteAccessException If somenetwork failure occured.
      */
-  
+
     public RemoteResource registerFrame(String id, String classname)
 	throws RemoteAccessException
     {
 	// Can we add new resources ?
 	if ( ! isframed )
 	    throw new RuntimeException("not a framed resource");
-	// Add it:
-	ByteArrayOutputStream bout    = new ByteArrayOutputStream();
-	DataOutputStream      out     = new DataOutputStream(bout);
 	try {
 	    Request req = createRequest();
 	    // Prepare the request:
 	    req.setMethod("REGISTER-FRAME");
 	    req.setContentType(admin.conftype);
-	    req.setURL(url);
-	    out.writeUTF((id == null) ? "" : id);
-	    out.writeUTF(classname);
-	    out.close();
-	    byte bits[] = bout.toByteArray();	    
+
+	    ResourceDescription dframe = new EmptyDescription(classname, id);
+	    ByteArrayOutputStream bout = new ByteArrayOutputStream();
+	    OutputStream out;
+	    if (debug) {
+		out = bout;
+	    } else {
+		out = new GZIPOutputStream(bout);
+	    }
+	    admin.writer.writeResourceDescription(dframe, out);
+	    byte bits[] = bout.toByteArray();
 	    req.setContentLength(bits.length);
+	    if (!debug) {
+		req.addTransferEncoding("gzip");
+	    }
 	    req.setOutputStream(new ByteArrayInputStream(bits));
+
 	    // Run it:
 	    Reply rep = admin.runRequest(req);
-	    // Decode the result and add it as a frame:
-	    DataInputStream in  = new DataInputStream(rep.getInputStream());
-	    RemoteResource  ret = admin.reader.readResource(url, id, in);
-	    // A nasty hack:
-	    PlainRemoteResource plain = (PlainRemoteResource) ret;
-
-	    //if (parent == null) {
+	    dframe = 
+		admin.reader.readResourceDescription(getInputStream(rep));
+	    id = dframe.getIdentifier();
+	    URL url = null;
 	    if (isFrame()) {
-		plain.url = new URL(url, url.getFile()+"?" + plain.identifier);
+		url = new URL(this.url, this.url.getFile()+"?" + id);
 	    } else {
-		plain.url = new URL(parent.toString() + 
-				    identifier+"?"+plain.identifier);
+		url = new URL(parent.toString() + 
+			      identifier+"?"+id);
 	    }
-	    // End nasty hack
-	    in.close();
+	    PlainRemoteResource frame  = 
+		new PlainRemoteResource(admin, parent, url, id, dframe);
+	    //insert it in the frame array
 	    if ( frames != null ) {
 		RemoteResource nf[] = new RemoteResource[frames.length+1];
 		System.arraycopy(frames, 0, nf, 0, frames.length);
-		nf[frames.length] = ret;
+		nf[frames.length] = frame;
 		frames = nf;
 	    } else {
 		frames    = new RemoteResource[1];
-		frames[0] = ret;
+		frames[0] = frame;
 	    }
-	    return ret;
+	    return frame;
 	} catch (RemoteAccessException rae) {
 	    throw rae;
 	} catch (Exception ex) {
@@ -661,7 +661,32 @@ public class PlainRemoteResource implements RemoteResource {
 	    throw new RemoteAccessException(ex.getMessage());
 	}
     }
-   
+
+    protected void createRemoteFrames() {
+	ResourceDescription dframes[] = description.getFrameDescriptions();
+	int                 len       = dframes.length;
+	this.frames                   = new RemoteResource[len];
+	for (int i = 0 ; i < len ; i++) {
+	    ResourceDescription dframe     = dframes[i];
+	    String              frameid    = dframe.getIdentifier();
+	    URL url = null;
+	    try {
+		if (isFrame()) {
+		    url = new URL(this.url, this.url.getFile()+"?" + frameid);
+		} else {
+		    url = new URL(parent.toString() + 
+				  identifier+"?"+frameid);
+		}
+	    } catch (MalformedURLException ex) {
+		ex.printStackTrace();
+		url = null;
+	    }
+	    PlainRemoteResource frame  = 
+		new PlainRemoteResource(admin, parent, url, frameid, dframe);
+	    frames[i] = frame;
+	}
+    }
+
     /**
      * Dump that resource to the given output stream.
      * @param prt A print stream to dump to.
@@ -676,15 +701,6 @@ public class PlainRemoteResource implements RemoteResource {
 	String classes[] = getClassHierarchy();
 	for (int i = 0 ; i < classes.length ; i++) 
 	    System.out.println("\t"+classes[i]);
-	// Dump attribute values:
-	Attribute attrs[]   = getAttributes();
-	Vector    query     = new Vector();
-	for (int i = 0 ; i < attrs.length ; i++) {
-	    if ( attrs[i] != null )
-		query.addElement(attrs[i].getName());
-	}
-	String attnames[] = new String[query.size()];
-	query.copyInto(attnames);
 	// Any frames available ?
 	if ( isframed && (frames != null) ) {
 	    System.out.println("+ "+frames.length+" frames.");
@@ -695,42 +711,79 @@ public class PlainRemoteResource implements RemoteResource {
 	}
 	// Run the query, and display results:
 	System.out.println("+ attributes: ");
-	Object values[] = getValues(attnames);
-	for (int i = 0 ; i < attnames.length ; i++) {
-	    Attribute a = attrs[lookupAttribute(attnames[i])];
-	    if ( values[i] != null )
-		prt.println("\t"+a.getName()+"="+a.stringify(values[i]));
-	    else 
-		prt.println("\t"+a.getName()+" <undef>");
+	AttributeDescription attrs[]   = getAttributes();
+	for (int i = 0 ; i < attrs.length ; i++) {
+	    Attribute att = attrs[i].getAttribute();
+	    if (att.checkFlag(Attribute.EDITABLE)) {
+		Object value = attrs[i].getValue();
+		if (value != null) {
+		    if (att instanceof SimpleAttribute) {
+			SimpleAttribute sa = (SimpleAttribute) att;
+			prt.println("\t"+att.getName()+"="+
+				    sa.pickle(attrs[i].getValue()));
+		    } else if (att instanceof ArrayAttribute) {
+			ArrayAttribute aa = (ArrayAttribute) att;
+			String values[] = aa.pickle(attrs[i].getValue());
+			prt.print("\t"+att.getName()+"=");
+			for (int j = 0 ; j < values.length ; j++) {
+			    if (j != 0)
+				prt.print(" | ");
+			    prt.print(values[j]);
+			}
+		    }
+		}
+		else
+		    prt.println("\t"+att.getName()+" <undef>");
+	    }
 	}
     }
 
-    PlainRemoteResource(AdminContext admin, String classes[]) {
-	this(admin, null, null, classes);
-    }
-		
-    PlainRemoteResource(AdminContext admin
-			, URL parent, String id
-			, String classes[]) {
-	this(admin, parent, id, null, classes);
+    /**
+     * reload the RemoteResource.
+     */
+    protected void update() 
+	throws RemoteAccessException
+    {
+	try {
+	    Request req = createRequest();
+	    // Prepare the request:
+	    req.setMethod("LOAD-RESOURCE");
+	    // Run it:
+	    Reply rep = admin.runRequest(req);
+	    InputStream in = getInputStream(rep);
+	    this.description = 
+		admin.reader.readResourceDescription(in);
+	    createRemoteFrames();
+	} catch (RemoteAccessException rae) {
+	    throw rae;
+	} catch (Exception ex) {
+	    throw new RemoteAccessException(ex.getMessage());
+	}
     }
 
-    PlainRemoteResource(AdminContext admin
-			, URL parent
-			, String identifier
-			, URL url
-			, String classes[]) {
-	this.admin      = admin;
-	this.identifier = identifier;
-	this.parent     = parent;
-	this.classes    = classes;
-	this.attributes = null;
-	this.values     = null;
-	// That's how we do it (!) - could make better
-	// [container implies filtered => break;]
+    PlainRemoteResource(AdminContext admin, 
+			URL parent, 
+			String identifier,
+			ResourceDescription description)
+    {
+	this(admin, parent, null, identifier, description);
+    }
+
+    PlainRemoteResource(AdminContext admin, 
+			URL parent,
+			URL url,
+			String identifier,
+			ResourceDescription description)
+    {
+	this.admin       = admin;
+	this.parent      = parent;
+	this.identifier  = identifier;
+	this.description = description;
+
+	String classes[] = description.getClassesAndInterfaces();
 	for (int i = 0 ; i < classes.length ; i++) {
 	    if (classes[i].equals(
-				"org.w3c.tools.resources.ContainerInterface")) 
+			       "org.w3c.tools.resources.ContainerInterface")) 
 		iscontainer = true;
 	    if (classes[i].equals("org.w3c.tools.resources.FramedResource"))
 		isframed = true;
@@ -740,24 +793,29 @@ public class PlainRemoteResource implements RemoteResource {
 			    "org.w3c.tools.resources.indexer.IndexersCatalog"))
 		isindexerscatalog = true;
 	}
-	// Build up that resource URL:
-	try {
-	    if ( url != null ) {
-		this.url = url;
-	    } else if (parent != null) {
+
+	if (url == null) {
+	    if (parent != null) {
 		String encoded = ((identifier == null) ? identifier :
 				  URLEncoder.encode(identifier));
 		String urlpart = iscontainer ? encoded+"/" : encoded;
-		this.url = ((identifier != null)
-			    ? new URL(parent.toString() + urlpart)
-			    : parent);
+		try {
+		    this.url = ((identifier != null)
+				? new URL(parent.toString() + urlpart)
+				: parent);
+		} catch (MalformedURLException ex) {
+		    ex.printStackTrace();
+		    this.url = null;
+		}
 	    } else {
 		this.url = null;
 	    }
-	} catch (MalformedURLException ex) {
-	    // Again, an implementation bug:
-	    throw new RuntimeException("invalid server URL");
+	} else {
+	    this.url = url;
 	}
+	createRemoteFrames();
     }
+
 }
 
+
