@@ -1,14 +1,19 @@
 // AuthUser.java
-// $Id: AuthUser.java,v 1.5.4.1 2000/01/21 13:19:56 bmahe Exp $
+// $Id: AuthUser.java,v 1.7 2000/08/16 21:37:34 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.auth ;
 
-import java.util.*;
+import java.util.Hashtable;
 
-import org.w3c.tools.resources.*;
-import org.w3c.jigsaw.http.*;
+import org.w3c.tools.resources.Attribute;
+import org.w3c.tools.resources.AttributeHolder;
+import org.w3c.tools.resources.AttributeRegistry;
+import org.w3c.tools.resources.Resource;
+import org.w3c.tools.resources.ResourceContext;
+import org.w3c.tools.resources.StringArrayAttribute;
+import org.w3c.tools.resources.StringAttribute;
 
 /**
  * The basic description of a user.
@@ -80,7 +85,6 @@ public class AuthUser extends Resource {
 	ATTR_GROUPS = AttributeRegistry.registerAttribute(cls, a) ;
     }
 
-
     /**
      * Get this user's name.
      * We use the resource identifier as the user name here.
@@ -174,3 +178,4 @@ public class AuthUser extends Resource {
 
 }
 
+
