@@ -1,16 +1,18 @@
 // URLDecoder.java
-// $Id: URLDecoder.java,v 1.8.4.1 2000/04/06 16:25:16 ylafon Exp $
+// $Id: URLDecoder.java,v 1.10 2000/08/16 21:37:38 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.forms ;
 
-import java.io.* ;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
+import java.io.Reader;
+
 import java.util.Hashtable ;
 import java.util.Enumeration ;
 
-import org.w3c.jigsaw.* ;
-
 /**
  * Form data decoder.
  * This class takes an InputStream and decodes it in compliance to the
@@ -26,7 +28,7 @@ public class URLDecoder {
     int         bsize    = 0 ;
     Reader      in       = null ;
     boolean     overide  = true ;
-    
+
     private void append (int c) {
 	if ( bsize+1 >= buffer.length ) {
 	    byte nb[] = new byte[buffer.length*2] ;
