@@ -1,11 +1,12 @@
 // EncodingAttribute.java
-// $Id: EncodingAttribute.java,v 1.2 1999/09/07 13:28:52 ylafon Exp $
+// $Id: EncodingAttribute.java,v 1.3 2000/08/16 21:37:38 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.frames ;
 
-import org.w3c.tools.resources.*;
+import org.w3c.tools.resources.Attribute;
+import org.w3c.tools.resources.StringAttribute;
 
 public class EncodingAttribute extends StringAttribute {
 
