@@ -1,13 +1,11 @@
 // HtmlStyle.java
-// $Id: HtmlStyle.java,v 1.5 1998/09/22 12:15:07 ylafon Exp $
+// $Id: HtmlStyle.java,v 1.6 2000/08/16 21:37:40 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.html ;
 
-import java.io.* ;
-import org.w3c.www.mime.*;
-
+import org.w3c.www.mime.MimeType;
 
 /**
  * a sample Style class for HTML documents
@@ -26,7 +24,7 @@ public class HtmlStyle {
     {
 	this.type = type;
     }
-    
+
     /**
      * append a string to the style buffer
      * @param str1 A string to be append
@@ -39,7 +37,7 @@ public class HtmlStyle {
 	else
 	    style.append(str1);
     }
-    
+
     /**
      * genereate a String representation that can be
      * append in a HTML document
