@@ -1,20 +1,28 @@
 // Client.java
-// $Id: Client.java,v 1.54.4.5 2000/04/06 09:34:40 ylafon Exp $
+// $Id: Client.java,v 1.66 2001/02/09 15:37:54 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.http;
 
-import java.io.*;
-import java.net.*;
+import java.io.DataOutputStream;
+import java.io.InputStream;
+import java.io.IOException;
 
-import org.w3c.tools.timers.*;
-import org.w3c.www.http.*;
-import org.w3c.www.mime.*;
+import java.net.InetAddress;
+
+import org.w3c.www.http.HTTP;
+import org.w3c.www.http.HttpParserException;
+
+import org.w3c.www.mime.MimeParser;
+import org.w3c.www.mime.MimeParserException;
+import org.w3c.www.mime.MimeParserFactory;
 
 import org.w3c.tools.resources.ProtocolException;
 import org.w3c.tools.resources.ResourceException;
 
+import org.w3c.tools.timers.EventHandler;
+
 /**
  * The request timeout event, to be delivered by the timer package.
  * Handling timers is expensive, and can be a bottleneck, this is the only
@@ -31,26 +39,6 @@ class RequestTimeout {
     }
 }
 
-/**
- * The Mime factory for creating requests out of the client transport streams.
- * This factory creates instances of <code>org.w3c.jigsaw.http.Request</code>
- * a server-specific subclass of the generic <code>org.w3c.www.http.HttpRequest
- * </code> class.
- * @see org.w3c.www.http.HttpRequest
- */
-
-class MimeClientFactory implements MimeParserFactory {
-    Client client = null;
-
-    public MimeHeaderHolder createHeaderHolder(MimeParser parser) {
-	return new Request(client, parser);
-    }
-
-    MimeClientFactory(Client client) {
-	this.client = client;
-    }
-}
-
 /**
  * Client instances keep track of a specific connection with a browser.
  * This abstract class is responsible for handling an HTTP connection, as
@@ -245,7 +233,13 @@ public abstract class Client implements EventHandler {
 	// The server doesn't want any keep connection
 	if ( ! server.getClientKeepConnection() )
 	    return false ;
-	return request.canKeepConnection() && reply.tryKeepConnection();
+	if (!request.canKeepConnection()) {
+	    if (reply.tryKeepConnection()) {
+		reply.addConnection("close");
+	    }
+	    return false;
+	}
+	return reply.tryKeepConnection();
     }
 
     /**
@@ -257,7 +251,7 @@ public abstract class Client implements EventHandler {
      */
 
     protected Request getNextRequest () 
-	throws ClientException
+	throws ClientException, IOException
     {
 	Request request = null ;
 	cont = false; // reinit the continue
@@ -289,7 +283,7 @@ public abstract class Client implements EventHandler {
      * @param is The reply's body that has to be chunk encoded.
      * @exception IOException If IO error occurs.
      */
-     
+
     protected int chunkTransfer(InputStream is)
 	throws IOException
     {
@@ -304,7 +298,10 @@ public abstract class Client implements EventHandler {
 
 	try {
 	    // Emit the reply stream:
-	    while ((got = is.read(buffer)) > 0) {
+	    while ((got = is.read(buffer)) >= 0) {
+		if (got == 0) {
+		    continue;
+		}
 		// Emit a full chunk: header first, followed by the body
 		// we dump the hexa size of the header backward
 		sgot = got;
@@ -326,6 +323,9 @@ public abstract class Client implements EventHandler {
 	} catch (IOException ex) {
 	    // To cope with Java's exec bug 
 	    // Anyway, if this really fails, the output will fail below too
+	    if (debug) {
+		ex.printStackTrace();
+	    }
 	}
 	// Emit the 0 chunk:
 	output.write(zeroChunk, 0, 3) ;
@@ -635,7 +635,7 @@ public abstract class Client implements EventHandler {
      * <strong>true</strong>, otherwise, just schedule an interruption
      * after the current request (if any) has been processed.
      */
-     
+
     protected synchronized void interruptConnection(boolean now) {
 	if ( running ) {
 	    interrupted = true;
@@ -682,7 +682,7 @@ public abstract class Client implements EventHandler {
      * @return A boolean, <strong>true</strong> if it is, 
      * <strong>false</strong> otherwise.
      */
-     
+
     public final synchronized boolean isRunning() {
 	return running;
     }
@@ -846,7 +846,7 @@ public abstract class Client implements EventHandler {
 	this.server     = server;
 	this.identifier = identifier;
 	this.debug      = server.getClientDebug() ;
-	this.factory    = new MimeClientFactory(this);
+	this.factory    = server.getMimeClientFactory(this);
     }
-    
+
 }
