@@ -1,16 +1,22 @@
 // CommonLogger.java
-// $Id: CommonLogger.java,v 1.25.4.7 2000/06/29 08:18:28 ylafon Exp $
+// $Id: CommonLogger.java,v 1.41 2001/02/20 02:27:27 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.http ;
 
-import java.io.* ;
-import java.util.Date ;
+import java.io.File;
+import java.io.IOException;
+import java.io.RandomAccessFile;
+
+import java.net.URL;
+
+import java.util.Date;
 
-import org.w3c.jigsaw.daemon.*;
 import org.w3c.jigsaw.auth.AuthFilter;
-import org.w3c.util.*;
+
+import org.w3c.util.ObservableProperties;
+import org.w3c.util.PropertyMonitoring;
 
 /**
  * The CommonLogger class implements the abstract Logger class.
@@ -88,6 +94,7 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
     protected int                  year        = -1   ;
     protected int                  month       = -1   ;
     protected int                  day         = -1   ;
+    protected int                  hour        = -1   ;
     protected int                  tz          = -1   ;
 
     /**
@@ -164,7 +171,7 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
 	    return true ;
 	}
     }
-    
+
     /**
      * Output the given message to the given RandomAccessFile.
      * This method makes its best effort to avoid one byte writes (which you
@@ -220,7 +227,7 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
 	    }
 	}
     }
-    
+
     protected void errlogmsg (String msg) {
 	if ( errlog != null ) {
 	    try {
@@ -232,7 +239,7 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
 	    }
 	}
     }
-    
+
     protected void tracemsg (String msg) {
 	if ( trace != null ) {
 	    try {
@@ -299,7 +306,7 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
 	this.day = day;
 
 	String ext = null;
-	if (month < 10) {
+	if (month < 9) {
 	    if (day < 10) {
 		ext = "_"+year+"_0"+(month+1)+"_0"+day;
 	    } else {
@@ -329,9 +336,9 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
     protected void openLogFile(int year, int month) {
 	this.year = year;
 	this.month = month;
-       
+
 	String ext = null;
-	if (month < 10)
+	if (month < 9)
 	    ext = "_"+year+"_0"+(month+1);
 	else
 	    ext = "_"+year+"_"+(month+1);
@@ -384,13 +391,28 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
 	} else {
 	    now = new Date(date + (tz*60*1000));
 	}
-
+	// check if we need to reset the timezone
+	if (hour == -1) {
+	    hour = now.getHours();
+	} else {
+	    int nhour = now.getHours();
+	    if (nhour != hour) {
+		hour = nhour;
+		tz = -1;
+	    }
+	}
 	if (rotateLevel > 0) {
 	    checkLogFile(now);
 	}
 
 	String user = (String) request.getState(AuthFilter.STATE_AUTHUSER);
-
+	URL urlst = (URL) request.getState(Request.ORIG_URL_STATE);
+	String requrl;
+	if (urlst == null) {
+	    requrl = request.getURL().toExternalForm();
+	} else {
+	    requrl = urlst.toExternalForm();
+	}
 	entry = client.getInetAddress().getHostAddress()
 	    + " " + "-"			  	   // user name
 	    + " " + ((user == null ) ? "-" : user) // auth user name
@@ -398,21 +420,22 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
 	    + (now.getDate() 		   	   // current date
 	       + "/" + monthnames[now.getMonth()]
 	       + "/" + (now.getYear() + 1900)
-	       + ((now.getHours() < 10)
-		  ? (":0" + now.getHours())
-		  : (":" + now.getHours()))
+	       + ((hour < 10)
+		  ? (":0" + hour)
+		  : (":" + hour))
 	       + ((now.getMinutes() < 10)
 		  ? (":0" + now.getMinutes())
 		  : (":" + now.getMinutes()))
 	       + ((now.getSeconds() < 10)
 		  ? (":0" + now.getSeconds())
 		  : (":" + now.getSeconds()))
-	       + " +0]")
+	       + " +0000]")
 	    + " \"" + request.getMethod()	// request line
-	    + " " + request.getURL()
+	    + " " + requrl
 	    + " " + request.getVersion()
 	    + "\" " + reply.getStatus()		// reply status
-	    + " " + nbytes			// # of emited bytes
+	    + " " + ((nbytes < 0 ) ? "-" :
+		     Integer.toString(nbytes)) // # of emited bytes
 	    + "\n" ;
 	logmsg (entry) ;
     }
@@ -491,7 +514,7 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
 	    return (new File(flogdir, filename)).getAbsolutePath() ;
 	}
     }
-    
+
     /**
      * Open this logger log file.
      */
@@ -561,7 +584,7 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
     /**
      * Save all pending data to stable storage.
      */
-    
+
     public synchronized void sync() {
 	try {
 	    if ((buffer != null) && (bufptr > 0)) {
@@ -627,9 +650,10 @@ public class CommonLogger extends Logger implements PropertyMonitoring {
     /**
      * Construct a new Logger instance.
      */
-     
+
     CommonLogger () {
 	this.msgbuf = new byte[128] ;
     }
 }
 
+
