@@ -1,15 +1,33 @@
 // Reply.java
-// $Id: Reply.java,v 1.29 1999/11/30 18:20:51 ylafon Exp $
+// $Id: Reply.java,v 1.32 2000/11/07 14:19:09 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.http ;
 
-import java.io.* ;
+import java.io.ByteArrayInputStream;
+import java.io.DataOutputStream;
+import java.io.FileDescriptor;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.io.UnsupportedEncodingException;
 
-import org.w3c.www.mime.*;
-import org.w3c.www.http.*;
-import org.w3c.tools.resources.*;
+import org.w3c.www.mime.MimeType;
+
+import org.w3c.www.http.HTTP;
+import org.w3c.www.http.HeaderValue;
+import org.w3c.www.http.HttpEntityMessage;
+import org.w3c.www.http.HttpFactory;
+import org.w3c.www.http.HttpMessage;
+import org.w3c.www.http.HttpMimeType;
+import org.w3c.www.http.HttpReplyMessage;
+import org.w3c.www.http.HttpRequestMessage;
+import org.w3c.www.http.HttpTokenList;
+
+import org.w3c.tools.resources.ReplyInterface;
+import org.w3c.tools.resources.RequestInterface;
+import org.w3c.tools.resources.ResourceFilter;
 
 public class Reply extends HttpReplyMessage implements ReplyInterface {
     protected static HttpMimeType  DEFAULT_TYPE = null;
@@ -58,7 +76,7 @@ public class Reply extends HttpReplyMessage implements ReplyInterface {
     public FileDescriptor getInputFileDescriptor() {
 	return null;
     }
-    
+
     public void setKeepConnection(boolean onoff) {
 	this.keep = onoff;
     }
@@ -134,7 +152,7 @@ public class Reply extends HttpReplyMessage implements ReplyInterface {
 	this.infilters = infilters;
     }
 
-    
+   
     protected OutputStream output = null;
 
     /**
@@ -198,16 +216,16 @@ public class Reply extends HttpReplyMessage implements ReplyInterface {
 	    if ( hasContentLength() || (is == null)) {
 		chunkable = Boolean.FALSE ;
 	    } else if ((major >= 1) && (minor >= 1)) {
-		String connections[] = getConnection();
+//		String connections[] = getConnection();
 		chunkable = Boolean.TRUE ;
-		if (connections != null) {
-		    for (int i = 0; i< connections.length; i++) {
-			if (connections[i].equalsIgnoreCase("close")) {
-			    chunkable = Boolean.FALSE;
-			}
-		    }
-		}
-		if (chunkable == Boolean.TRUE)
+//		if (connections != null) {
+//		    for (int i = 0; i< connections.length; i++) {
+//			if (connections[i].equalsIgnoreCase("close")) {
+//			    chunkable = Boolean.FALSE;
+//			}
+//		    }
+//		}
+//		if (chunkable == Boolean.TRUE)
 		    addTransferEncoding(chunked);
 	    } else {
 		chunkable = Boolean.FALSE ;
@@ -246,9 +264,9 @@ public class Reply extends HttpReplyMessage implements ReplyInterface {
      * @param msg The reply content.
      */
     public void setContent (String msg) {
-	setContent(msg, "ISO8859_1");
+	setContent(msg, "ISO-8859-1");
     }
-    
+
     /**
      * Create a new Reply instance for the given client.
      * @param client The client to who this reply  is directed.
