@@ -1,18 +1,16 @@
 // UnixProp.java
-// $Id: UnixProp.java,v 1.5 1998/01/22 14:03:36 bmahe Exp $
+// $Id: UnixProp.java,v 1.6 2000/08/16 21:37:41 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.http;
 
-import java.io.* ;
-import java.util.* ;
+import org.w3c.tools.resources.Attribute;
+import org.w3c.tools.resources.AttributeRegistry;
+import org.w3c.tools.resources.IntegerAttribute;
+import org.w3c.tools.resources.StringAttribute;
 
-import org.w3c.tools.resources.*;
-import org.w3c.www.http.*;
-//import org.w3c.jigsaw.forms.* ;
-import org.w3c.jigsaw.daemon.*;
-import org.w3c.jigsaw.config.*;
+import org.w3c.jigsaw.config.PropertySet;
 
 /**
  * A wrapper class to give access to editable properties through a resource.
@@ -58,3 +56,4 @@ class UnixProp extends PropertySet {
     }
 }
 
+
