@@ -1,18 +1,24 @@
 // SocketClient.java
-// $Id: SocketClient.java,v 1.17.4.6 2000/04/11 03:42:15 ylafon Exp $
+// $Id: SocketClient.java,v 1.23 2000/08/16 21:37:42 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.http.socket ;
 
-import java.io.* ;
-import java.net.*;
-import java.util.*;
+import java.io.BufferedInputStream;
+import java.io.DataOutputStream;
+import java.io.IOException;
+import java.io.PrintStream;
 
-import org.w3c.jigsaw.http.*;
-import org.w3c.tools.resources.* ;
-import org.w3c.www.mime.*;
-import org.w3c.www.http.*;
+import java.net.InetAddress;
+import java.net.Socket;
+import java.net.SocketException;
+
+import org.w3c.jigsaw.http.Client;
+import org.w3c.jigsaw.http.ClientException;
+import org.w3c.jigsaw.http.httpd;
+
+import org.w3c.tools.resources.ServerInterface;
 
 /**
  * This class implements the object that handles client connections. 
@@ -143,10 +149,10 @@ public class SocketClient extends Client implements Runnable {
 		ex.printStackTrace();
 	    }
 	} finally {
-	    thread = null;
 	    if ( ! pool.clientConnectionFinished(this) ) {
 		pool.clientFinished(this);
 	    }
+	    thread = null;
 	}
     }
 
@@ -200,10 +206,12 @@ public class SocketClient extends Client implements Runnable {
      */
 
     protected boolean idleConnection() {
-	if ( trace )
-	    System.out.println(this+": idleConnection.");
-	idle = true;
-	return ! pool.notifyIdle(this);
+	synchronized (state) {
+	    if ( trace )
+		System.out.println(this+": idleConnection.");
+	    idle = true;
+	    return ! pool.notifyIdle(this);
+	}
     }
 
     /**
@@ -213,10 +221,12 @@ public class SocketClient extends Client implements Runnable {
      */
 
     protected void usedConnection() {
-	if ( trace )
-	    System.out.println(this+": usedConnection.");
-	idle = false;
-	pool.notifyUse(this) ;
+	synchronized (state) {
+	    if ( trace )
+		System.out.println(this+": usedConnection.");
+	    idle = false;
+	    pool.notifyUse(this) ;
+	}
     }
 
     /**
@@ -279,7 +289,7 @@ public class SocketClient extends Client implements Runnable {
     public final int getBindCount() {
 	return bindcount;
     }
-     
+
     /**
      * Create an empty client, that will be ready to work.
      * The created client will run and wait for it to be <code>bind</code>
@@ -300,5 +310,4 @@ public class SocketClient extends Client implements Runnable {
 	this.alive    = true;
     }
 
-
 }
