@@ -1,27 +1,58 @@
 // JigsawServletContext.java
-// $Id: JigsawServletContext.java,v 1.26 2000/03/03 16:04:07 bmahe Exp $
+// $Id: JigsawServletContext.java,v 1.31 2000/11/10 09:52:45 bmahe Exp $
 // (c) COPYRIGHT MIT and INRIA, 1998.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.servlet;
 
-import java.io.*;
-import java.net.*;
-import java.util.*;
+import java.io.ByteArrayOutputStream;
+import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.PrintStream;
+import java.io.PrintWriter;
+import java.io.RandomAccessFile;
 
-import javax.servlet.*;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.net.URLConnection;
+
+import java.util.Date;
+import java.util.Enumeration;
+import java.util.Hashtable;
+
+import javax.servlet.RequestDispatcher;
+import javax.servlet.Servlet;
+import javax.servlet.ServletContext;
+
+import org.w3c.util.EmptyEnumeration;
+import org.w3c.util.ObservableProperties;
+import org.w3c.util.PropertyMonitoring;
+
+import org.w3c.tools.resources.event.StructureChangedAdapter;
+import org.w3c.tools.resources.event.StructureChangedEvent;
+
+import org.w3c.tools.resources.AttributeHolder;
+import org.w3c.tools.resources.DirectoryResource;
+import org.w3c.tools.resources.FileResource;
+import org.w3c.tools.resources.FramedResource;
+import org.w3c.tools.resources.InvalidResourceException;
+import org.w3c.tools.resources.LookupResult;
+import org.w3c.tools.resources.LookupState;
+import org.w3c.tools.resources.ProtocolException;
+import org.w3c.tools.resources.Resource;
+import org.w3c.tools.resources.ResourceFrame;
+import org.w3c.tools.resources.ResourceReference;
+import org.w3c.tools.resources.ServerInterface;
+
+import org.w3c.jigsaw.frames.HTTPFrame;
 
-import org.w3c.util.*;
-import org.w3c.tools.resources.store.*;
-import org.w3c.tools.resources.event.*;
-import org.w3c.tools.resources.*;
-import org.w3c.jigsaw.frames.*;
 import org.w3c.jigsaw.proxy.ForwardFrame;
 import org.w3c.jigsaw.resources.VirtualHostResource;
 import org.w3c.jigsaw.http.httpd;
 
 /**
- * @version $Revision: 1.26 $
+ * @version $Revision: 1.31 $
  * @author  Benot Mah (bmahe@w3.org)
  */
 public class JigsawServletContext extends StructureChangedAdapter
@@ -79,7 +110,7 @@ public class JigsawServletContext extends StructureChangedAdapter
 				   logfile+"] : "+ex.getMessage());
 	    }
 	}
- 
+
 	void log(Exception ex, String msg) {
 	    log(msg+" : "+ex.getClass().getName()+" ("+ex.getMessage()+")");
 	}
@@ -265,11 +296,11 @@ public class JigsawServletContext extends StructureChangedAdapter
     /**
      * ServletContext implementation - Log a message.
      */
-    
+
     public void log(String msg) {
 	logger.log(msg);
     }
-    
+
     /**
      * @deprecated since jsdk2.1
      */
@@ -283,22 +314,94 @@ public class JigsawServletContext extends StructureChangedAdapter
 
     /**
      * ServletContext implementation - Translate a piece of path.
+     * @param path the virtual path to translate
+     * @param rr_root the Root ResourceReference
+     * @param rr the target ResourceReference
+     * @return the real path
      */
-
-    public String getRealPath(String path) {
-	httpd             server  = (httpd)getServer();
-	ResourceReference rr_root = server.getRootReference();
-	File              dir     = getRootDirectory(rr_root,
-						     reference);
-	if (dir == null) {
-	    String message = "Error: unable to compute root directory";
-	    throw new RuntimeException(message);
+    protected static String getRealPath(String path, 
+					ResourceReference rr_root,
+					ResourceReference rr) 
+    {
+	ResourceReference local_root = getLocalRoot(rr_root, rr);
+	try {
+	    FramedResource root = (FramedResource)local_root.lock();
+	    LookupState    ls   = new LookupState(path);
+	    LookupResult   lr   = new LookupResult(local_root);
+	    if (root.lookup(ls,lr)) {
+		ResourceReference  target = lr.getTarget();
+		if (target != null) {
+		    try {
+			FramedResource res = (FramedResource)target.lock();
+			if (res instanceof FileResource) {
+			    File file = ((FileResource)res).getFile();
+			    return file.getAbsolutePath();
+			} else if (res instanceof DirectoryResource) {
+			    DirectoryResource dir = (DirectoryResource) res;
+			    return dir.getDirectory().getAbsolutePath();
+			    //return getFilePath(dir);
+			}
+		    } finally {
+			target.unlock();
+		    }
+		}
+	    }
+	    return null;
+	} catch (InvalidResourceException ex) {
+	    return null;
+	} catch (org.w3c.tools.resources.ProtocolException pex) {
+	    return null;
+	} finally {
+	    local_root.unlock();
 	}
-	return new File(dir, path).getAbsolutePath();
     }
 
-    protected static File getRootDirectory(ResourceReference rr_root,
-					   ResourceReference ref) {
+    /**
+     * ServletContext implementation - Translate a piece of path.
+     * @param path the virtual path to translate
+     * @return the real path
+     */
+    public String getRealPath(String path) {
+	ResourceReference rr_root = ((httpd) getServer()).getRootReference();
+	return getRealPath(path, rr_root, reference);
+    }
+
+    protected static String getFilePath(DirectoryResource dir) {
+	HTTPFrame frame = 
+	    (HTTPFrame)dir.getFrame("org.w3c.jigsaw.frames.HTTPFrame");
+	String indexes[] = frame.getIndexes();
+	if (indexes != null) {
+	    for (int i = 0 ; i < indexes.length ; i++) {
+		String index = indexes[i];
+		if ( index != null && index.length() > 0) {
+		    ResourceReference rr = dir.lookup(index);
+		    if (rr != null) {
+			try {
+			    FramedResource ri = (FramedResource) rr.lock();
+			    if (ri instanceof FileResource) {
+				FileResource fr = (FileResource) ri;
+				File file = fr.getFile();
+				return file.getAbsolutePath();
+			    } else {
+				// we don't know 
+				return null;
+			    }
+			} catch (InvalidResourceException ex) {
+			} finally {
+			    rr.unlock();
+			}
+		    }
+		}
+	    }
+	    return dir.getDirectory().getAbsolutePath();
+	} else {
+	    return dir.getDirectory().getAbsolutePath();
+	}
+    }
+
+    protected static ResourceReference getLocalRoot(ResourceReference rr_root,
+						    ResourceReference ref) 
+    {
 	try {
 	    FramedResource root = (FramedResource)rr_root.lock();
 	    if (root instanceof VirtualHostResource) {
@@ -315,7 +418,7 @@ public class JigsawServletContext extends StructureChangedAdapter
 			rr = ref;
 		    }
 		} catch (InvalidResourceException ex) {
-		    return null;
+		    return rr_root;
 		} finally {
 		    ref.unlock();
 		}
@@ -325,46 +428,37 @@ public class JigsawServletContext extends StructureChangedAdapter
 			res = (FramedResource)rr.lock();
 			rrp = res.getParent();
 			if ((rrp == rr_root) || (rrp == null)) {
-			    if (res.definesAttribute("directory")) {
-				return (File)res.getValue("directory", null);
-			    } else {
-				// root doesn't define directory attribute
-				return lookupLocalRoot(res, ref);
-			    }
+			    return getLocalRoot(rr, ref);
 			}
 		    } catch (InvalidResourceException ex) {
-			return null;
+			return rr_root;
 		    } finally {
 			rr.unlock();
 		    }
 		    rr = rrp;
 		}
-	    } else if (root.definesAttribute("directory")) {
-		return (File)root.getValue("directory", null);
 	    } else {
-		// root doesn't define directory attribute
-		return lookupLocalRoot(root, ref);
+		try {
+		    FramedResource res = (FramedResource)rr_root.lock();
+		    ForwardFrame   ffr = (ForwardFrame)
+			res.getFrame("org.w3c.jigsaw.proxy.ForwardFrame");
+		    if (ffr == null) {
+			return rr_root;
+		    } else {
+			ResourceReference rr = ffr.getLocalRootResource();
+			return getLocalRoot(rr, ref);
+		    }
+		} catch (InvalidResourceException ex) {
+		    return rr_root;
+		}
 	    }
 	} catch (InvalidResourceException ex) {
-	    return null;
+	    return rr_root;
 	} finally {
 	    rr_root.unlock();
 	}
     }
 
-    protected static File lookupLocalRoot(FramedResource res,
-					  ResourceReference ref) {
-	// the only solution, we have a Forward frame
-	ForwardFrame ffr = (ForwardFrame)
-	    res.getFrame("org.w3c.jigsaw.proxy.ForwardFrame");
-	if (ffr == null) {
-	    return null;
-	} else {
-	    ResourceReference rr = ffr.getLocalRootResource();
-	    return getRootDirectory(rr, ref);
-	}
-    }
-
     /**
      * ServletContext implementation - Get server informations.
      */
@@ -387,7 +481,7 @@ public class JigsawServletContext extends StructureChangedAdapter
      * support for name clashes though.
      * @param name The attribute name.
      */
-    
+
     public Object getAttribute(String name) {
 	Object attribute = attributes.get(name);
 	if (attribute != null) {
@@ -437,8 +531,8 @@ public class JigsawServletContext extends StructureChangedAdapter
 	// @@ not implemented @@
 	return null;
     }
-    
-    
+
+   
 
 
     /**
@@ -498,7 +592,8 @@ public class JigsawServletContext extends StructureChangedAdapter
      */
     public RequestDispatcher getRequestDispatcher(String urlpath) {
 	return JigsawRequestDispatcher.getRequestDispatcher(urlpath, 
-							   (httpd)getServer());
+							   (httpd)getServer(),
+							    reference);
     }
 
     /**
@@ -538,7 +633,7 @@ public class JigsawServletContext extends StructureChangedAdapter
     public int getMinorVersion() {
 	return 2;
     }
-    
+
     public ServletContext getContext(String uripath) {
 	if (uripath == null)
 	    return null;
@@ -583,41 +678,27 @@ public class JigsawServletContext extends StructureChangedAdapter
     public URL getResource(String path) 
 	throws MalformedURLException
     {
-	httpd             server  = (httpd)getServer();
-	ResourceReference rr_root = server.getRootReference();
-	File              dir     = getRootDirectory(rr_root,
-						     reference);
-	if (dir == null) {
-	    String message = "Error: unable to compute root directory";
-	    throw new RuntimeException(message);
-	}
-	File file = new File(dir, path);
+	// FIXME? is it allowed?
+	File file = new File(path);
 	if (file.exists()) {
 	    return new URL("file", "", file.getAbsolutePath());
 	}
-	return null;
+	String realpath = getRealPath(path);
+	if (realpath != null) {
+	    file = new File(realpath);
+	    if (file.exists()) {
+		return new URL("file", "", file.getAbsolutePath());
+	    } else {
+		return null;
+	    }
+	} else {
+	    // it could be a virtual resource
+	    // check that it exists (on server)
+	    // FIXME (Virtual host)
+	    return null;
+	}
     }
 
-//     public URL getResource(String path) 
-// 	throws MalformedURLException
-//     {
-// 	if (path.length() > 0 && path.charAt(0) == '/')
-// 	    path = path.substring(1);
-// 	if (File.separatorChar != '/')
-// 	    path.replace('/', File.separatorChar);
-// 	//String dir = getServletDirectory().getAbsolutePath();
-// 	String dir = getServletDirectory().getAbsolutePath();
-// 	File file = new File(dir, path);
-// 	if (! file.exists())
-// 	    return null;
-// 	String url = file.getAbsolutePath();
-// 	if (File.separatorChar != '/')
-// 	    url = url.replace(File.separatorChar, '/');
-// 	if (url.length() > 0 && url.charAt(0) != '/')
-// 	    url = '/' + url;
-// 	return new URL("file", "", url);
-//     }
-
     public InputStream getResourceAsStream(String path) {
 	try {
 	    URL resource = getResource(path);
