@@ -1,22 +1,41 @@
 // ServletWrapperFrame.java
-// $Id: ServletWrapperFrame.java,v 1.12.4.2 2000/03/14 17:50:50 bmahe Exp $
+// $Id: ServletWrapperFrame.java,v 1.21 2001/01/16 10:23:12 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.jigsaw.servlet;
 
-import java.io.* ;
-import java.util.*;
+import javax.servlet.ServletException;
+import javax.servlet.UnavailableException;
 
-import javax.servlet.*;
+import java.io.IOException;
+import java.io.PipedInputStream;
+import java.io.PipedOutputStream;
 
-import org.w3c.tools.resources.store.*;
-import org.w3c.util.*;
-import org.w3c.www.mime.*;
-import org.w3c.www.http.*;
-import org.w3c.jigsaw.http.*;
-import org.w3c.jigsaw.frames.*;
-import org.w3c.tools.resources.*;
+import org.w3c.www.mime.MimeType;
+
+import org.w3c.www.http.HTTP;
+import org.w3c.www.http.HttpEntityMessage;
+import org.w3c.www.http.HttpMessage;
+import org.w3c.www.http.HttpReplyMessage;
+
+import org.w3c.jigsaw.http.httpd;
+import org.w3c.jigsaw.http.HTTPException;
+import org.w3c.jigsaw.http.Reply;
+import org.w3c.jigsaw.http.Request;
+
+import org.w3c.jigsaw.frames.HTTPFrame;
+
+import org.w3c.tools.resources.FramedResource;
+import org.w3c.tools.resources.LookupResult;
+import org.w3c.tools.resources.LookupState;
+import org.w3c.tools.resources.ProtocolException;
+import org.w3c.tools.resources.ReplyInterface;
+import org.w3c.tools.resources.RequestInterface;
+import org.w3c.tools.resources.Resource;
+import org.w3c.tools.resources.ResourceException;
+import org.w3c.tools.resources.ResourceFrame;
+import org.w3c.tools.resources.ServerInterface;
 
 import org.w3c.tools.resources.ProtocolException;
 import org.w3c.tools.resources.ResourceException;
@@ -112,7 +131,46 @@ public class ServletWrapperFrame extends HTTPFrame {
 	Reply reply = createDefaultReply(request, HTTP.OK);
 	reply.setContentType(MimeType.TEXT_HTML);
 	try {
-	    wrapper.service(request, reply);
+	    if (request.hasState(JigsawHttpServletResponse.INCLUDED)) {
+		wrapper.service(request, reply);
+	    } else {
+		PipedInputStream pis = new PipedInputStream();
+		PipedOutputStream pos = new PipedOutputStream(pis);
+		reply.setState(JigsawHttpServletResponse.STREAM, pos);
+		reply.setStream(pis);
+		Object o = new Object();
+		reply.setState(JigsawHttpServletResponse.MONITOR, o);
+		// wait until the reply is constructed by the processing thread
+		ServerInterface server = getServer();
+		if (server instanceof httpd) {
+		    synchronized (o) {
+			wrapper.service(request, reply);
+			o.wait((long)((httpd)server).getRequestTimeOut());
+		    }
+		    Object strm;
+		    strm = reply.getState(JigsawHttpServletResponse.STREAM);
+		    if (strm != null) {
+			// it is a timeout
+			try {
+			    pis.close();
+			    pos.close();
+			} catch (IOException ex) {};
+			if (strm instanceof PipedOutputStream) {
+			    Thread r;
+			    r = (Thread) reply.getState(ServletWrapper.RUNNER);
+			    if (r != null) {
+				r.interrupt();
+			    }
+			    throw new ServletException("Timed out");
+			}
+		    }
+		} else {
+		    synchronized (o) {
+			wrapper.service(request, reply);
+			o.wait();
+		    }
+		}
+	    }
 	} catch (UnavailableException uex) {
 	     reply = request.makeReply(HTTP.SERVICE_UNAVAILABLE);
 	     if (uex.isPermanent()) {
@@ -142,7 +200,7 @@ public class ServletWrapperFrame extends HTTPFrame {
 	}
 	return reply;
     }
-    
+
     /**
      * Jigsaw's lookup on servlets.
      * Once here, we have reached a leaf servlet (or at least the remaining
