@@ -1,12 +1,11 @@
 // DNSEntry.java
-// $Id: DNSEntry.java,v 1.2 1999/07/13 08:23:13 ylafon Exp $
+// $Id: DNSEntry.java,v 1.3 2000/08/16 21:37:50 ylafon Exp $
 // (c) COPYRIGHT MIT, INRIA and Keio, 1996-1999.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.tools.log;
 
-import java.lang.*;
-import java.io.*;
+import java.io.Serializable;
 
 /**
  * This class implements a very small DNS entry, aka a host
@@ -17,7 +16,7 @@ public class DNSEntry implements Serializable {
     String  host     = null;
     boolean resolved = false;
     int     tries    = 0;
-  
+
     boolean isResolved() {
 	return resolved;
     }
@@ -54,3 +53,4 @@ public class DNSEntry implements Serializable {
     }
 }
 
+
