@@ -1,14 +1,25 @@
 // FramedResource.java
-// $Id: FramedResource.java,v 1.22.4.2 2000/01/20 16:18:49 bmahe Exp $
+// $Id: FramedResource.java,v 1.26 2000/08/16 21:37:52 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.tools.resources ;
 
-import java.util.* ;
-import java.io.* ;
+import java.util.EventObject;
+import java.util.Hashtable;
 
-import org.w3c.tools.resources.event.*;
+import java.io.PrintStream;
+
+import org.w3c.tools.resources.event.AttributeChangedEvent;
+import org.w3c.tools.resources.event.AttributeChangedListener;
+import org.w3c.tools.resources.event.Events;
+import org.w3c.tools.resources.event.FrameEvent;
+import org.w3c.tools.resources.event.FrameEventListener;
+import org.w3c.tools.resources.event.ResourceEvent;
+import org.w3c.tools.resources.event.ResourceEventMulticaster;
+import org.w3c.tools.resources.event.ResourceEventQueue;
+import org.w3c.tools.resources.event.StructureChangedEvent;
+import org.w3c.tools.resources.event.StructureChangedListener;
 
 /**
  * A FramedResource manage frames which are called during the
@@ -133,7 +144,6 @@ public class FramedResource extends Resource
 	ATTR_OID = AttributeRegistry.registerAttribute(cls, a);
     }
 
-
     public Object getClone(Object values[]) {
 	FramedResource clone   = (FramedResource) super.getClone(values);
 	clone.framesRef      = new Hashtable(3);
@@ -164,39 +174,39 @@ public class FramedResource extends Resource
      * This handles the <code>FRAME_ADDED</code> kind of events.
      * @param evt The FrameEvent.
      */
-  
+
     public void frameAdded(FrameEvent evt) {
 	if (debugEvent) 
 	    displayEvent( this, evt );
 	if (! isUnloaded()) 
 	    markModified();
     }
-  
+
     /**
      * This handles the <code>FRAME_MODIFIED</code> kind of events.
      * @param evt The event describing the change.
      */
-  
+
     public void frameModified(FrameEvent evt) {
 	if (debugEvent) 
 	    displayEvent( this, evt );
 	if (! isUnloaded()) 
 	    markModified();
     }
-  
+
     /**
      * A frame is about to be removed
      * This handles the <code>FRAME_REMOVED</code> kind of events.
      * @param evt The event describing the change.
      */
-  
+
     public void frameRemoved(FrameEvent evt) {
 	if (debugEvent) 
 	    displayEvent( this, evt );
 	if (! isUnloaded()) 
 	    markModified();
     }
-   
+
     /**
      * Initialize and attach a new ResourceFrame to that resource.
      * @param frame An uninitialized ResourceFrame instance.
@@ -209,7 +219,7 @@ public class FramedResource extends Resource
 	addAttributeChangedListener(frame);
 	frame.registerResource(this);
     }
-  
+
     /**
      * Register a new ResourceFrame if none (from the same class) has been 
      * registered.
@@ -242,7 +252,7 @@ public class FramedResource extends Resource
      * Unregister a resource frame from the given resource.
      * @param frame The frame to unregister from the resource.
      */
-    
+
     public synchronized void unregisterFrame(ResourceFrame frame) {
 	super.unregisterFrame(frame);
 	frame.unregisterResource(this);
@@ -309,7 +319,6 @@ public class FramedResource extends Resource
 	return rr;
     }
 
-
     /**
      * Get The FrameReference of the given frame, or <strong>null</strong>
      * if the frame is not registered.
@@ -398,19 +407,18 @@ public class FramedResource extends Resource
      * Remove an attribute change listener.
      * @param l The listener to remove.
      */
-    
+
     public void removeAttributeChangedListener(AttributeChangedListener l) {
 	attrListener = ResourceEventMulticaster.remove(attrListener, l);
     }
 
-
     /**
      * post an attribute change event. Actually this kind of event should 
      * not be posted. So fire them!
      * @param idx The index of the attribute that has changed.
      * @param newvalue The new value for that attribute.
      */
-  
+
     protected void postAttributeChangeEvent(int idx, Object newvalue) {
 	if (eventDisabled())
 	    return;
@@ -431,7 +439,6 @@ public class FramedResource extends Resource
 	if ( attrListener != null )
 	    attrListener.attributeChanged(evt);
     }
-  
 
     /**
      * Add a structure change listener.
@@ -446,7 +453,7 @@ public class FramedResource extends Resource
      * Remove a structure change listener.
      * @param l The listener to remove.
      */
-    
+
     public void removeStructureChangedListener(StructureChangedListener l) {
 	structListener = ResourceEventMulticaster.remove(structListener, l);
     }
@@ -488,7 +495,6 @@ public class FramedResource extends Resource
 	}
     }
 
-
     /**
      * Fire an structure change event.
      * @param evt the StructureChangedEvent to fire.
@@ -519,9 +525,21 @@ public class FramedResource extends Resource
      * cleanup required.
      */
     public void notifyUnload() {
+	//
+	// direct notification
+	//
+	ResourceFrame frames[] = getFrames();
+	if ( frames != null ) {
+	    for (int i = 0 ; i < frames.length ; i++) {
+		if ( frames[i] == null )
+		    continue;
+		frames[i].notifyUnload();
+	    }
+	}
 	fireStructureChangedEvent(Events.RESOURCE_UNLOADED);
 	super.notifyUnload();
     }
+
     /**
      * Delete this Resource instance, and remove it from its store.
      * This method will erase definitely this resource, for ever, by removing
