@@ -1,21 +1,23 @@
 // ServerInterface.java
-// $Id: ServerInterface.java,v 1.7 2000/02/11 13:20:02 bmahe Exp $
+// $Id: ServerInterface.java,v 1.8 2000/08/16 21:37:53 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.tools.resources ;
 
-import java.net.*;
-import java.io.*;
+import java.net.URL;
+
+import java.io.File;
+
+import org.w3c.util.ObservableProperties;
 
-import org.w3c.util.*;
 import org.w3c.jigsaw.daemon.ServerHandler;
-import org.w3c.tools.resources.indexer.*;
+
+import org.w3c.tools.resources.indexer.IndexersCatalog;
 
 //FIXME ServerHandler should be in this package
 public interface ServerInterface extends ServerHandler {
 
-
     /**
      * Another nice way of reporting errors from a Resource.
      * @param from The resource that trigered the error.
@@ -34,7 +36,7 @@ public interface ServerInterface extends ServerHandler {
      * Checkpoint all cached data, by saving them to disk.
      */
     public void checkpoint();
-  
+
     /**
      * Dynamically change the root resource for the server.
      * This is kind a dangerous operation !
@@ -44,7 +46,7 @@ public interface ServerInterface extends ServerHandler {
      * if we couldn't load the given resource.
      */
     public ResourceReference loadRoot(String name);
-  
+
     /** 
      * Get this server properties.
      */
@@ -72,7 +74,7 @@ public interface ServerInterface extends ServerHandler {
      * Get the client's debug flags from the properties.
      */
     public boolean getClientDebug();
-    
+
     /**
      * Does this server wants clients to try keeping connections alive ?
      */
@@ -112,7 +114,7 @@ public interface ServerInterface extends ServerHandler {
      * Get the server current root resource.
      */
     public FramedResource getRoot();
-  
+
     /**
      * Get the server URL.
      */
