@@ -1,18 +1,47 @@
 // Resourcestoremanager.java
-// $Id: ResourceStoreManager.java,v 1.12 1999/12/01 14:31:12 ylafon Exp $
+// $Id: ResourceStoreManager.java,v 1.17 2000/12/07 12:38:08 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.tools.resources.store ;
 
-import org.w3c.tools.resources.*;
+import org.w3c.tools.resources.AttributeHolder;
+import org.w3c.tools.resources.InvalidResourceException;
+import org.w3c.tools.resources.Resource;
+import org.w3c.tools.resources.ResourceContext;
+import org.w3c.tools.resources.ResourceReference;
+import org.w3c.tools.resources.ResourceSpace;
+import org.w3c.tools.resources.ServerInterface;
+import org.w3c.tools.resources.SpaceEntry;
+
 import org.w3c.tools.resources.serialization.Serializer;
-import org.w3c.tools.resources.event.*;
 
-import java.io.* ;
-import java.util.* ;
+import org.w3c.tools.resources.event.ResourceEventQueue;
 
-import org.w3c.util.*;
+import java.io.BufferedInputStream;
+import java.io.BufferedReader;
+import java.io.BufferedWriter;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileReader;
+import java.io.FileWriter;
+import java.io.FilenameFilter;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.ObjectInputStream;
+import java.io.PrintStream;
+import java.io.Reader;
+import java.io.Serializable;
+import java.io.Writer;
+
+import java.util.Enumeration;
+import java.util.Hashtable;
+import java.util.Vector;
+
+import org.w3c.util.AsyncLRUList;
+import org.w3c.util.LRUAble;
+import org.w3c.util.LRUList;
+import org.w3c.util.Status;
 
 class Reference implements ResourceReference {
 
@@ -137,7 +166,7 @@ class StoreEntry implements LRUAble, Serializable {
     public LRUAble getNext() {
 	return next;
     }
-  
+
     public LRUAble getPrev() {
 	return prev;
     }
@@ -145,7 +174,7 @@ class StoreEntry implements LRUAble, Serializable {
     public void setNext(LRUAble next) {
 	this.next = next;
     }
-  
+
     public void setPrev(LRUAble prev) {
 	this.prev = prev;
     }
@@ -311,7 +340,7 @@ class StoreEntry implements LRUAble, Serializable {
 	}
 	return true;
     }
-    
+
     /**
      * Shutdown the store.
      */
@@ -332,7 +361,7 @@ class StoreEntry implements LRUAble, Serializable {
 	    store.save();
 	}
     }
-  
+
     void initialize(ResourceStoreManager manager) {
 	this.manager    = manager;
 	this.references = new Hashtable();
@@ -356,7 +385,6 @@ class StoreEntry implements LRUAble, Serializable {
 
 }
 
-
 class StoreManagerSweeper extends Thread {
     ResourceStoreManager manager = null ;
     boolean              killed  = false ;
@@ -476,7 +504,7 @@ public class ResourceStoreManager implements ResourceSpace {
 	    eventQueue = new ResourceEventQueue();
 	return eventQueue;
     }
-  
+
     protected final int getMaxLoadedStore() {
 	return maxLoadedStore ;
     }
@@ -697,7 +725,6 @@ public class ResourceStoreManager implements ResourceSpace {
 	}
     }
 
-
     /**
      * update the old index file. Load it and save it with the serializer.
      * @param the index file (serialized hashtable of StoreEntry)
@@ -842,7 +869,7 @@ public class ResourceStoreManager implements ResourceSpace {
 	if ( entry != null )
 	    lru.toHead(entry);
     }
-  
+
     protected boolean used(String rep) {
 	Enumeration e = entries.elements();
 	NewStoreEntry entry = null;
@@ -887,8 +914,8 @@ public class ResourceStoreManager implements ResourceSpace {
 	    System.out.println(entry.getKey()+" : "+entry.getRepository());
 	}
     }
-    
-    
+
+   
     /**
      * Try to salvage the resource store manager state.
      * That's pretty easy and robust, it should really work well if no
@@ -989,7 +1016,7 @@ public class ResourceStoreManager implements ResourceSpace {
 				       "), no StoreEntry for its space entry");
 	return entry.addResource(resource, defs);
     }
-  
+
     /**
      * Save this resource to the StoreEntry of the space entry.
      * @param sentry The resource space entry
@@ -1155,7 +1182,44 @@ public class ResourceStoreManager implements ResourceSpace {
 	    // FIXME : unload index hashtable ?
 	}
     }
-    
+
+    /**
+     * Implementation of Status interface
+     * Display statistics about usage of the resource store manager
+     * @returns a String containing a fragment of HTML
+     */
+    public String getHTMLStatus() {
+	Enumeration elements = entries.elements();
+	int nb_entries = 0;
+	int nb_entries_store = 0;
+	while (elements.hasMoreElements()) {
+	    NewStoreEntry entry = (NewStoreEntry) elements.nextElement();
+	    if (entry.references != null) {
+		nb_entries += entry.references.size();
+	    }
+	    if (entry.store != null) {
+		ResourceStoreImpl st = (ResourceStoreImpl) entry.store;
+		nb_entries_store += st.resources.size();
+	    }
+	}
+	StringBuffer sb = new StringBuffer();
+	sb.append("<table border=\"1\" class=\"store\">\n"
+		  + "<caption>Resource Store usage</caption>\n"
+		  + "<tr><th>Loaded Stores</th>"
+		  + "<th>Loaded Entries</th></tr>\n");
+	sb.append("<tr><td>");
+	sb.append(loadedStore);
+	sb.append(" / ");
+	sb.append(maxLoadedStore);
+	sb.append("</td><td>");
+	sb.append(nb_entries);
+	sb.append(" / ");
+	sb.append(nb_entries_store);
+	sb.append("</td>\n</table>");
+	return sb.toString();
+    }
+
+
     /**
      * Enumerate the name (ie identifiers) of the space entry children.
      * @param sentry The space entry.
@@ -1260,6 +1324,7 @@ public class ResourceStoreManager implements ResourceSpace {
 	//    salvage();
 	//    displayIndex();
     }
-  
+
 }
 
+
