@@ -1,13 +1,12 @@
 // TreeNode.java
-// $Id: TreeNode.java,v 1.5 1999/02/19 16:23:37 ylafon Exp $
+// $Id: TreeNode.java,v 1.6 2000/08/16 21:37:57 ylafon Exp $
 // Author: Jean-Michel.Leon@sophia.inria.fr
 // (c) COPYRIGHT MIT and INRIA, 1997.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.tools.widgets;
 
-import java.awt.*;
-
+import java.awt.Image;
 
 /**
  * The representation of a node of a TreeBrowser.
@@ -33,7 +32,7 @@ public class TreeNode {
     int children = NOCHILD;
     boolean selected = false;
 
-    
+   
     TreeNode(Object item, String label,
 	     NodeHandler handler, Image icon, int level) {
 	this.item = item;
@@ -43,7 +42,7 @@ public class TreeNode {
 	this.handler = handler;
     }
 
-    
+   
    /**
     * Gets the item.
     */   
@@ -51,7 +50,6 @@ public class TreeNode {
 	return item;
     }
 
-
    /**
     * Gets the label.
     *
