@@ -1,11 +1,14 @@
 // ByteRangeOutputStream.java
-// $Id: ByteRangeOutputStream.java,v 1.2 1998/01/22 14:26:16 bmahe Exp $
+// $Id: ByteRangeOutputStream.java,v 1.3 2000/08/16 21:37:58 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.www.http ;
 
-import java.io.*;
+import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.RandomAccessFile;
 
 public class ByteRangeOutputStream extends InputStream {
     int              firstp = -1;
