@@ -1,11 +1,12 @@
 // ContentLengthInputStream.java
-// $Id: ContentLengthInputStream.java,v 1.9 1999/02/17 22:15:34 ylafon Exp $
+// $Id: ContentLengthInputStream.java,v 1.11 2000/08/16 21:37:58 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.www.http;
 
-import java.io.* ;
+import java.io.IOException;
+import java.io.InputStream;
 
 /**
  * The content length input stream is used internally to return entity bodies.
@@ -98,7 +99,7 @@ public class ContentLengthInputStream extends InputStream {
 	}
 	return len ;
     }
-    
+
     public long skip (long n) 
 	throws IOException 
     {
@@ -127,6 +128,18 @@ public class ContentLengthInputStream extends InputStream {
 	}
     }
 
+    /**
+     * do we support mark() ?
+     * it depends on the underlying InputStream
+     * @return a boolean, true if mark is supported
+     */
+    public boolean markSupported() {
+	if( in == null )
+	    return false;
+	else
+	    return in.markSupported();
+    }
+
     /**
      * Builds a new content-length input stream.
      * This stream acts as a normal stream except that it will return 
