@@ -1,12 +1,11 @@
 // HttpCacheControl.java
-// $Id: HttpCacheControl.java,v 1.16 1999/11/29 18:06:15 ylafon Exp $
+// $Id: HttpCacheControl.java,v 1.17 2000/08/16 21:37:59 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.www.http;
 
-import java.io.*;
-import java.util.*;
+import java.util.Vector;
 
 /**
  * The parsed cache-control directive of HTTP/1.1
@@ -51,7 +50,7 @@ public class HttpCacheControl extends BasicValue {
      * @param id The field identifier.
      * @return A boolean.
      */
-    
+
     private final boolean checkDirective(int id) {
 	return (defined & id) != 0;
     }
@@ -64,7 +63,7 @@ public class HttpCacheControl extends BasicValue {
     private final void setDirective(int id) {
 	defined |= id;
     }
-    
+
     /**
      * Mark the given field as being unset.
      * @param id The field identifier.
@@ -77,7 +76,7 @@ public class HttpCacheControl extends BasicValue {
     /**
      * Recompute the byte value for this header.
      */
-    
+
     protected void updateByteValue() {
 	// Dump the value, using my own version of the StringBuffer:
 	HttpBuffer buf = new HttpBuffer();
@@ -615,7 +614,7 @@ public class HttpCacheControl extends BasicValue {
 	    onlyifcached = true;
 	}
     }
-     
+
     /**
      * Is the public flag set ?
      * @return A boolean.
@@ -686,7 +685,7 @@ public class HttpCacheControl extends BasicValue {
      * Is the no-transform flag set ?
      * @return A boolean.
      */
-    
+
     public boolean checkNoTransform() {
 	validate();
 	return notransform;
