@@ -1,16 +1,18 @@
 // HttpChallenge.java
-// $Id: HttpChallenge.java,v 1.10.4.1 2000/01/14 14:36:33 ylafon Exp $
+// $Id: HttpChallenge.java,v 1.19 2001/03/07 18:53:40 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.www.http;
 
-import org.w3c.util.*;
+import org.w3c.util.ArrayDictionary;
+
 import java.lang.CloneNotSupportedException;
 
 public class HttpChallenge extends BasicValue {
     String          scheme = null;
     ArrayDictionary params = null;
+    ArrayDictionary unqparams = null;
 
     /**
      * get a copy of the challenge, used to add some output value
@@ -53,10 +55,19 @@ public class HttpChallenge extends BasicValue {
 	    if ( HttpParser.nextItem(raw, it) < 0 )
 		error("Invalid challenge: no param value.");
 	    it.ioff = it.start;
-	    HttpParser.unquote(raw, it);
-	    if ( params == null )
-		params = new ArrayDictionary(5, 5);
-	    params.put(key, it.toString(raw));
+	    int offset = HttpParser.skipSpaces(raw, it);
+	    if ((offset < raw.length) && (raw[offset] == '\"')) {
+		HttpParser.unquote(raw, it);
+		if ( params == null ) {
+		    params = new ArrayDictionary(5, 5);
+		}
+		params.put(key, it.toString(raw));
+	    } else {
+		if ( unqparams == null ) {
+		    unqparams = new ArrayDictionary(5, 5);
+		}
+		unqparams.put(key, it.toString(raw));
+	    }
 	    ps.prepare();
 	}
     }
@@ -65,15 +76,38 @@ public class HttpChallenge extends BasicValue {
 	HttpBuffer buf = new HttpBuffer();
 	buf.append(scheme);
 	buf.append(' ');
-	int len = params.size();
-	for (int i = 0 ; len > 0 ; i++) {
-	    String key = (String) params.keyAt(i);
-	    if ( key == null )
-		continue;
-	    buf.appendQuoted(key, (byte) '=', (String) params.elementAt(i));
-	    len--;
-	    if (len > 0) {
-		buf.append((byte)',');
+	int len = 0;
+	if (params != null) {
+	    len = params.size();
+	}
+	if (unqparams != null) {
+	    len += unqparams.size();
+	}
+	if (params != null) {
+	    int plen = params.size();
+	    for (int i = 0 ; i < plen ; i++) {
+		String key = (String) params.keyAt(i);
+		if ( key == null )
+		    continue;
+		buf.appendQuoted(key, (byte) '=', 
+				 (String) params.elementAt(i));
+		len--;
+		if (len > 0) {
+		    buf.append((byte)',');
+		}
+	    }
+	}
+	if (unqparams != null) {
+	    int unqlen = unqparams.size();
+	    for (int i = 0 ; i < unqlen ; i++) {
+		String key = (String) unqparams.keyAt(i);
+		if ( key == null )
+		    continue;
+		buf.append(key, (byte) '=', (String) unqparams.elementAt(i));
+		len--;
+		if (len > 0) {
+		    buf.append((byte)',');
+		}
 	    }
 	}
 	raw  = buf.getByteCopy();
@@ -105,20 +139,48 @@ public class HttpChallenge extends BasicValue {
 
     public String getAuthParameter(String name) {
 	validate();
-	return (params == null) ? null : (String) params.get(name);
+	String res = null;
+	if (params != null) {
+	    res = (String) params.get(name);
+	}
+	if (res == null) {
+	    if (unqparams != null) {
+		res = (String) unqparams.get(name);
+	    }  
+	}
+	return res;
     }
 
     /**
      * Set an auth parameter value.
      * @param name The name of the parameter to set.
      * @param value The new value for this parameter.
+     * @param quoted If true, the value will be quoted
      */
 
-    public void setAuthParameter(String name, String value) {
+    public void setAuthParameter(String name, String value, boolean quoted) {
 	invalidateByteValue();
-	if ( params == null )
-	    params = new ArrayDictionary(4, 4);
-	params.put(name, value);
+	if (quoted) {
+	    if ( params == null ) {
+		params = new ArrayDictionary(4, 4);
+	    }
+	    params.put(name, value);
+	} else {
+	    if ( unqparams == null ) {
+		unqparams = new ArrayDictionary(4, 4);
+	    }
+	    unqparams.put(name, value);	    
+	}
+    }
+
+    /**
+     * Set an auth parameter value.
+     * @param name The name of the parameter to set.
+     * @param value The new value for this parameter.
+     * The value will be quoted
+     */
+    public void setAuthParameter(String name, String value) {
+	setAuthParameter(name, value, true);
     }
 
     HttpChallenge(boolean isValid) {
