@@ -1,11 +1,15 @@
 // MimeParserReplyFactory.java
-// $Id: MimeParserReplyFactory.java,v 1.2 1998/01/22 14:29:47 bmahe Exp $
+// $Id: MimeParserReplyFactory.java,v 1.3 2000/08/16 21:38:01 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.www.http;
 
-import org.w3c.www.mime.*;
+
+import org.w3c.www.mime.MimeHeaderHolder;
+import org.w3c.www.mime.MimeParser;
+import org.w3c.www.mime.MimeParserFactory;
+
 
 /**
  * The MIME parse factory for HTTP replies.
