@@ -1,17 +1,31 @@
 // HttpBasicServer.java
-// $Id: HttpBasicServer.java,v 1.31.4.6 2000/03/25 01:20:24 ylafon Exp $
+// $Id: HttpBasicServer.java,v 1.52 2001/02/13 15:24:34 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.www.protocol.http;
 
-import java.util.*;
-import java.io.*;
-import java.net.*;
+import java.util.Date;
 
-import org.w3c.www.mime.*;
-import org.w3c.www.http.*;
-import org.w3c.util.*;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.io.PrintStream;
+
+import java.net.InetAddress;
+import java.net.UnknownHostException;
+
+import org.w3c.www.mime.MimeHeaderHolder;
+import org.w3c.www.mime.MimeParser;
+import org.w3c.www.mime.MimeParserException;
+import org.w3c.www.mime.MimeParserFactory;
+
+import org.w3c.www.http.HTTP;
+import org.w3c.www.http.HttpEntityMessage;
+import org.w3c.www.http.HttpMessage;
+import org.w3c.www.http.HttpReplyMessage;
+import org.w3c.www.http.HttpRequestMessage;
+import org.w3c.www.http.HttpStreamObserver;
 
 /**
  * The basic server class, to run requests.
@@ -98,6 +112,8 @@ public class HttpBasicServer extends HttpServer {
      */
     protected void setHostAddr(InetAddress hostAddrs[]) {
 	this.addrs = hostAddrs;
+	// reset the pointer in case the number of ip diminished
+	addrptr = 0;
 	// FIXME now defaults to 300s (5mn) but needs to be a parameter
 	lookupLimit = new Date(System.currentTimeMillis() + 300 * 1000 );
     }
@@ -132,7 +148,9 @@ public class HttpBasicServer extends HttpServer {
 		    hostAddrs    = new InetAddress[1];
 		    hostAddrs[0] = InetAddress.getByName(host);
 		}
-		setHostAddr(hostAddrs);
+		if (hostAddrs != null) {
+		    setHostAddr(hostAddrs);
+		}
 	    } catch (UnknownHostException ex) {
 		String msg = ("The host name ["+host+"] couldn't be resolved. "
 			      + "Details: \""+ex.getMessage()+"\"");
@@ -203,6 +221,9 @@ public class HttpBasicServer extends HttpServer {
 	} catch (HttpException hex) {
 	    // unable to update, will continue with the old version
 	    // as it may be a temporary DNS problem
+	    if (addrs == null) {
+		throw new IOException(hex.getMessage());
+	    }
 	}
 	for (int loop = 0 ; loop < addrs.length ; loop++) {
 	    InetAddress addr = null;
@@ -213,6 +234,10 @@ public class HttpBasicServer extends HttpServer {
 		i = (i+1) % addrs.length;
 	    } while ( i != addrptr );
 	    addrptr = (addrptr+1) % addrs.length;
+	    if (addr == null) {
+		throw new IOException("Host "+host+" resolved to a null"
+				      + " InetAddr");
+	    }
 	    try {
 		conn = new HttpBasicConnection(this
 					       , connid++
@@ -335,6 +360,8 @@ public class HttpBasicServer extends HttpServer {
 	    try {
 		manager.waitForConnection(this);
 	    } catch (InterruptedException ex) {
+		// interrupted, probably a timeout -> fail
+		return null;
 	    }
 	}
     }
@@ -371,7 +398,6 @@ public class HttpBasicServer extends HttpServer {
                                + ", ka="+keepalive);
     }
 
-
     /**
      * HttpServer implementation - Initialize this server to its target.
      * @param manager The central HTTP manager.
@@ -419,7 +445,7 @@ public class HttpBasicServer extends HttpServer {
     protected boolean isTwoStage_10(Request request) {
 	return request.hasOutputStream();
     }
-    
+
     /**
      * Is this request a two stage request.
      * @return A boolean, <strong>true</strong> if the request is two
@@ -500,7 +526,7 @@ public class HttpBasicServer extends HttpServer {
 	    reply = (Reply) p.parse(manager.isLenient());
 	    // "eat" the 100 replies
 	    while ((reply.getStatus() / 100) == 1 ) {
-		reply = (Reply) p.parse();
+		reply = (Reply) p.parse(manager.isLenient());
 	    }
 	} catch (IOException ex) {
 	} catch (MimeParserException ex) {
@@ -537,7 +563,7 @@ public class HttpBasicServer extends HttpServer {
 	    os.flush();
 	    if ( o != null ) 
 		notifyObserver(o, new ConnectedEvent(this, request, os));
-	    reply = (Reply) p.parse();
+	    reply = (Reply) p.parse(manager.isLenient());
 	} catch (IOException ex) {
 	    // Ok, we should give it another chance:
 	    return null;
@@ -556,11 +582,11 @@ public class HttpBasicServer extends HttpServer {
 	    // Finish the request normally:
 	    request.emit(os, Request.EMIT_BODY|Request.EMIT_FOOTERS);
 	    os.flush();
-	    reply = (Reply) p.parse();
+	    reply = (Reply) p.parse(manager.isLenient());
 	    // if we don't have any observer, we should eat the 100 continue!
 	    if ( o == null) {
 		while ((reply.getStatus() / 100) == 1 ) {
-		    reply = (Reply) p.parse();
+		    reply = (Reply) p.parse(manager.isLenient());
 		}
 	    }
 	}
@@ -589,10 +615,11 @@ public class HttpBasicServer extends HttpServer {
 	MimeParser   p     = conn.getParser();
 	Reply        reply = null;
 
-	if ( request.hasProxy() )
+	if ( request.hasProxy() ) {
 	    request.addProxyConnection("Keep-Alive");
-	else
+	} else {
 	    request.addConnection("Keep-Alive");
+	}
 	try {
 	    request.emit(os, Request.EMIT_HEADERS);
 	    os.flush();
@@ -605,10 +632,21 @@ public class HttpBasicServer extends HttpServer {
 		request.emit(os, Request.EMIT_BODY|Request.EMIT_FOOTERS);
 		os.flush();
 	    }
-	    reply = (Reply) p.parse();
+	    reply = (Reply) p.parse(manager.isLenient());
 	} catch (IOException ex) {
-	    // Ok, we should give it another chance: as we might have reused
-	    // a stale connection
+	    // at this point, we try to parse the reply if we have a body
+	    if (isTwoStage_10(request)) {
+		try {
+		    reply = (Reply) p.parse(manager.isLenient());
+		} catch (MimeParserException mex) {
+		    // a stale connection?
+		    return null;
+		}
+		try {
+		    request.getOutputStream().close();
+		} catch (Exception cex) {};
+		return reply;
+	    }
 	    return null;
 	} catch (MimeParserException ex) {
 	}
@@ -647,11 +685,32 @@ public class HttpBasicServer extends HttpServer {
 		notifyObserver(o, new ContinueEvent(this, request));
 	}
 	// Then emit the body:
-	request.emit(os, Request.EMIT_BODY|Request.EMIT_FOOTERS);
-	os.flush();
+	try {
+	    request.emit(os, Request.EMIT_BODY|Request.EMIT_FOOTERS);
+	    os.flush();
+	} catch (IOException ex) {
+	    // at this point, we try to parse the reply if we have a body
+	    if (isTwoStage_10(request)) {
+		try {
+		    reply = (Reply) p.parse(manager.isLenient());
+		} catch (MimeParserException mex) {
+		    // perhaps nothing so...
+		    throw ex;
+		}
+		if (reply != null) {
+                    // close the request stream
+		    try {
+			request.getOutputStream().close();
+		    } catch (Exception cex) {};
+		    return reply;
+		}
+	    }
+	    // no reply throw the exception again
+	    throw ex;
+	}
 	// HTTP 100 status codes *are* forbidden here:
 	try {
-	    reply = (Reply) p.parse();
+	    reply = (Reply) p.parse(manager.isLenient());
 	} catch (MimeParserException ex) {
 	    // be nice to lamers
 	}
@@ -698,10 +757,31 @@ public class HttpBasicServer extends HttpServer {
 	    }
 	}
 	// Then emit the body:
-	request.emit(os, Request.EMIT_BODY|Request.EMIT_FOOTERS);
-	os.flush();
 	try {
-	    reply = (Reply) p.parse();
+	    request.emit(os, Request.EMIT_BODY|Request.EMIT_FOOTERS);
+	    os.flush();
+	} catch (IOException ex) {
+	    // at this point, we try to parse the reply if we have a body
+	    if (isTwoStage_10(request)) {
+		try {
+		    reply = (Reply) p.parse(manager.isLenient());
+		} catch (MimeParserException mex) {
+		    // perhaps nothing so...
+		    throw ex;
+		}
+		if (reply != null) {
+                    // close the request stream
+		    try {
+			request.getOutputStream().close();
+		    } catch (Exception cex) {};
+		    return reply;
+		}
+	    }
+	    // no reply throw the exception again
+	    throw ex;
+	}
+	try {
+	    reply = (Reply) p.parse(manager.isLenient());
 	    while ((reply.getStatus() / 100) == 1) {
 		// If we already faked an event, skip that one:
 		if ( eventfaked ) {
@@ -712,7 +792,7 @@ public class HttpBasicServer extends HttpServer {
 		if ( o != null ) 
 		    notifyObserver(o, new ContinueEvent(this, request, reply));
 		// Get next reply:
-		reply = (Reply) p.parse();
+		reply = (Reply) p.parse(manager.isLenient());
 	    }
 	    // Now, we know about that server, update infos:
 	    if ( reply != null )
@@ -722,7 +802,7 @@ public class HttpBasicServer extends HttpServer {
 	}
 	return reply;
     }
-    
+
     /**
      * Exceute given request on given conection, according to server.
      * @param conn The connection to use to run that request.
@@ -805,10 +885,11 @@ public class HttpBasicServer extends HttpServer {
 		// Some connection ready, try using it:
 		if (request.hasOutputStream()) {
 		    int length = request.getContentLength();
-		    if (length != -1)
+		    if (length != -1) {
 			request.getOutputStream().mark(length+1);
-		    else // FIXME fixed length for unknown stream length
+		    } else { // FIXME fixed length for unknown stream length
 			request.getOutputStream().mark(1024*64); 
+		    }
 		}
 		try {
 		    if ((reply = doRequest(conn, request)) == null) {
@@ -824,16 +905,22 @@ public class HttpBasicServer extends HttpServer {
 			// Get rid of that useless connection:
 			conn.markIdle(true);
 		    }
-		} catch (IOException ioex) {
+		} catch (MimeParserException mex) {
+		    throw (mex);
+		} catch (Throwable ioex) {
 		    if (debug)
 			ioex.printStackTrace();
 		    // connection 1.0 failed so it was not a cached connection
 		    // restore the body if ther was one.
+		    try {
 			if (request.hasOutputStream()) {
 			    request.getOutputStream().reset();
 			}
-			// Get rid of that useless connection:
-			conn.markIdle(true);
+		    } catch (IOException mrex) {
+			// mark/reset not supported on the stream
+		    }
+		    // Get rid of that useless connection:
+		    conn.markIdle(true);
 		}
 	    }
 	    // Did the request really failed ?
