@@ -1,16 +1,26 @@
 // HttpMuxServer.java
-// $Id: HttpMuxServer.java,v 1.13 2000/02/29 15:01:55 ylafon Exp $  
+// $Id: HttpMuxServer.java,v 1.14 2000/08/16 21:38:02 ylafon Exp $  
 // (c) COPYRIGHT MIT and INRIA, 1997.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.www.protocol.http;
 
-import java.io.*;
+import java.io.BufferedOutputStream;
+import java.io.DataOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.io.PrintStream;
 
-import org.w3c.www.mux.*;
-import org.w3c.www.mime.*;
-import org.w3c.www.http.*;
+import org.w3c.www.mux.MuxSession;
 
+import org.w3c.www.mime.MimeHeaderHolder;
+import org.w3c.www.mime.MimeParser;
+import org.w3c.www.mime.MimeParserException;
+import org.w3c.www.mime.MimeParserFactory;
+
+import org.w3c.www.http.HttpMessage;
+import org.w3c.www.http.HttpReplyMessage;
 
 public class HttpMuxServer extends HttpServer {
     private static final String PROTOCOL = "http|mux";
@@ -61,7 +71,7 @@ public class HttpMuxServer extends HttpServer {
     protected boolean isTwoStage(Request requset) {
 	return requset.hasOutputStream();
     }
-    
+
     // FIXME doc
     protected void notifyObserver(RequestObserver obs
 				  , Request request
