@@ -1,14 +1,11 @@
 // HttpServerState.java
-// $Id: HttpServerState.java,v 1.6 2000/02/29 15:01:55 ylafon Exp $
+// $Id: HttpServerState.java,v 1.7 2000/08/16 21:38:03 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
 package org.w3c.www.protocol.http ;
 
-import java.util.*;
-
-import org.w3c.www.mime.*;
-import org.w3c.util.*;
+import java.util.Vector;
 
 class HttpServerState {
     HttpServer server = null;
@@ -75,3 +72,4 @@ class HttpServerState {
     }
 }
 
+
