@@ -1,14 +1,16 @@
 // ActiveStream.java
-// $Id: ActiveStream.java,v 1.27 1999/12/06 13:43:59 ylafon Exp $
+// $Id: ActiveStream.java,v 1.28 2000/08/16 21:38:03 ylafon Exp $
 // (c) COPYRIGHT MIT and INRIA, 1996.
 // Please first read the full copyright statement in file COPYRIGHT.html
 
-
 package org.w3c.www.protocol.http.cache;
 
-import java.io.*;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+
+import org.w3c.util.ThreadCache;
 
-import org.w3c.util.*;
 import org.w3c.www.protocol.http.Request;
 import org.w3c.www.protocol.http.Reply;
 
@@ -19,7 +21,7 @@ class ActiveInputStream extends InputStream {
     byte buffer[] = new byte[2048];
     int  off      = 0;
     int  len      = 0;
-    
+
     boolean closed      = false;
     boolean interrupted = false;
 
@@ -76,7 +78,7 @@ class ActiveInputStream extends InputStream {
 	closed = true;
 	notifyAll();
     }
-    
+
     public synchronized void interrupt() {
 	interrupted = true;
 	closed      = true;
@@ -154,7 +156,7 @@ public class ActiveStream implements Runnable {
     OutputStream      dst        = null;
     boolean           dstClosed  = false;
     TeeMonitor        monitor    = null;
-    
+
     public void run() {
 
 	byte    buffer[] = new byte[2048];
